vtkColorSeries

Struct vtkColorSeries 

pub struct vtkColorSeries(/* private fields */);
stores a list of colors.

The vtkColorSeries stores palettes of colors. There are several default palettes (or schemes) available and functions to control several aspects of what colors are returned. In essence a color scheme is set and then the number of colors and individual color values may be requested.

For a web page showcasing the default palettes, see: VTKColorSeriesPatches; ColorSeriesPatches was used to generate this table.

It is also possible to add schemes beyond the default palettes. Whenever \a SetColorScheme is called with a string for which no palette already exists, a new, empty palette is created. You may then use \a SetNumberOfColors and \a SetColor to populate the palette. You may not extend default palettes by calling functions that alter a scheme; if called while a predefined palette is in use, they will create a new non-default scheme and populate it with the current palette before continuing.

The “Brewer” palettes are courtesy of Cynthia A. Brewer (Dept. of Geography, Pennsylvania State University) and under the Apache License. See the source code for details.

Implementations

Source

impl vtkColorSeries

pub fn new() -> Self

Creates a new vtkColorSeries wrapped inside vtkNew