vtkKochanekSpline

Struct vtkKochanekSpline 

pub struct vtkKochanekSpline(/* private fields */);
computes an interpolating spline using a Kochanek basis.

Implements the Kochanek interpolating spline described in: Kochanek, D., Bartels, R., “Interpolating Splines with Local Tension, Continuity, and Bias Control,” Computer Graphics, vol. 18, no. 3, pp. 33-41, July 1984. These splines give the user more control over the shape of the curve than the cardinal splines implemented in vtkCardinalSpline. Three parameters can be specified. All have a range from -1 to 1.

Tension controls how sharply the curve bends at an input point. A value of -1 produces more slack in the curve. A value of 1 tightens the curve.

Continuity controls the continuity of the first derivative at input points.

Bias controls the direction of the curve at it passes through an input point. A value of -1 undershoots the point while a value of 1 overshoots the point.

These three parameters give the user broad control over the shape of the interpolating spline. The original Kochanek paper describes the effects nicely and is recommended reading.

@sa vtkSpline vtkCardinalSpline

Implementations

Source

impl vtkKochanekSpline

pub fn new() -> Self

Creates a new vtkKochanekSpline wrapped inside vtkNew