pub struct vtkParametricCrossCap(/* private fields */);Expand description
Generate a cross-cap.
vtkParametricCrossCap generates a cross-cap which is a non-orientable self-intersecting single-sided surface. This is one possible image of a projective plane in three-space.
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricCrossCap
impl vtkParametricCrossCap
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricCrossCap wrapped inside vtkNew