pub struct vtkParametricDini(/* private fields */);Expand description
Generate Dini’s surface.
vtkParametricDini generates Dini’s surface. Dini’s surface is a surface that possesses constant negative Gaussian curvature
For further information about this surface, please consult https://en.wikipedia.org/wiki/Dini%27s_surface
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricDini
impl vtkParametricDini
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricDini wrapped inside vtkNew