pub struct vtkParametricEllipsoid(/* private fields */);Expand description
Generate an ellipsoid.
vtkParametricEllipsoid generates an ellipsoid. If all the radii are the same, we have a sphere. An oblate spheroid occurs if RadiusX = RadiusY > RadiusZ. Here the Z-axis forms the symmetry axis. To a first approximation, this is the shape of the earth. A prolate spheroid occurs if RadiusX = RadiusY < RadiusZ.
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricEllipsoid
impl vtkParametricEllipsoid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricEllipsoid wrapped inside vtkNew