pub struct vtkParametricFigure8Klein(/* private fields */);Expand description
Generate a figure-8 Klein bottle.
vtkParametricFigure8Klein generates a figure-8 Klein bottle. A Klein bottle is a closed surface with no interior and only one surface. It is unrealisable in 3 dimensions without intersecting surfaces. It can be realised in 4 dimensions by considering the map \f$F:R^2 \rightarrow R^4\f$ given by:
- \f$f(u,v) = ((r*cos(v)+a)cos(u),(rcos(v)+a)sin(u),rsin(v)cos(u/2),rsin(v)*sin(u/2))\f$
This representation of the immersion in \f$R^3\f$ is formed by taking two Mobius strips and joining them along their boundaries, this is the so called “Figure-8 Klein Bottle”
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricFigure8Klein
impl vtkParametricFigure8Klein
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricFigure8Klein wrapped inside vtkNew