vtkParametricPluckerConoid

Struct vtkParametricPluckerConoid 

pub struct vtkParametricPluckerConoid(/* private fields */);
Generate Plucker’s conoid surface.

vtkParametricPluckerConoid generates Plucker’s conoid surface parametrically. Plucker’s conoid is a ruled surface, named after Julius Plucker. It is possible to set the number of folds in this class via the parameter ‘N’.

For more information, see the Wikipedia page on Plucker’s Conoid. @warning I haven’t done any special checking on the number of folds parameter, N. @par Thanks: Tim Meehan

Implementations

Source

impl vtkParametricPluckerConoid

pub fn new() -> Self

Creates a new vtkParametricPluckerConoid wrapped inside vtkNew