pub struct vtkParametricSpline(/* private fields */);Expand description
parametric function for 1D interpolating splines
vtkParametricSpline is a parametric function for 1D interpolating splines. vtkParametricSpline maps the single parameter u into a 3D point (x,y,z) using three instances of interpolating splines. This family of 1D splines is guaranteed to be parameterized in the interval [0,1]. Attempting to evaluate outside this interval will cause the parameter u to be clamped in the range [0,1].
When constructed, this class creates instances of vtkCardinalSpline for each of the x-y-z coordinates. The user may choose to replace these with their own instances of subclasses of vtkSpline.
@warning If you wish to tessellate the spline, use the class vtkParametricFunctionSource.
@sa vtkSpline vtkKochanekSpline vtkCardinalSpline
Implementations
Sourceimpl vtkParametricSpline
impl vtkParametricSpline
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricSpline wrapped inside vtkNew