pub struct vtkParametricSuperEllipsoid(/* private fields */);Expand description
Generate a superellipsoid.
vtkParametricSuperEllipsoid generates a superellipsoid. A superellipsoid is a versatile primitive that is controlled by two parameters n1 and n2. As special cases it can represent a sphere, square box, and closed cylindrical can.
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
Also see: http://paulbourke.net/geometry/superellipse/
@warning Care needs to be taken specifying the bounds correctly. You may need to carefully adjust MinimumU, MinimumV, MaximumU, MaximumV.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricSuperEllipsoid
impl vtkParametricSuperEllipsoid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricSuperEllipsoid wrapped inside vtkNew