Module vtkCommonCore
Source - vtkAffineCharArray
- affine implicit array of char.
- vtkAffineDoubleArray
- affine implicit array of double.
- vtkAffineFloatArray
- affine implicit array of float.
- vtkAffineIdTypeArray
- affine implicit array of vtkIdType.
- vtkAffineIntArray
- affine implicit array of int.
- vtkAffineLongArray
- affine implicit array of long.
- vtkAffineLongLongArray
- affine implicit array of long long.
- vtkAffineShortArray
- affine implicit array of short.
- vtkAffineSignedCharArray
- affine implicit array of signed char.
- vtkAffineUnsignedCharArray
- affine implicit array of unsigned char.
- vtkAffineUnsignedIntArray
- affine implicit array of unsigned int.
- vtkAffineUnsignedLongArray
- affine implicit array of unsigned long.
- vtkAffineUnsignedLongLongArray
- affine implicit array of unsigned long long.
- vtkAffineUnsignedShortArray
- affine implicit array of unsigned short.
- vtkAnimationCue
- a seqin an animation.
- vtkArchiver
- Writes an archive
- vtkBitArray
- dynamic, self-adjusting array of bits
- vtkBitArrayIterator
- Iterator for vtkBitArray.
- vtkBoxMuellerRandomSequence
- Gaussian sequence of pseudo random numbers implemented with the Box-Mueller transform
- vtkByteSwap
- perform machine dependent byte swapping
- vtkCallbackCommand
- supports function callbacks
- vtkCharArray
- dynamic, self-adjusting array of char
- vtkCollection
- create and manipulate ordered lists of objects
- vtkCollectionIterator
- iterator through a vtkCollection.
- vtkCompositeCharArray
- composite implicit array of char.
- vtkCompositeDoubleArray
- composite implicit array of double.
- vtkCompositeFloatArray
- composite implicit array of float.
- vtkCompositeIdTypeArray
- composite implicit array of vtkIdType.
- vtkCompositeIntArray
- composite implicit array of int.
- vtkCompositeLongArray
- composite implicit array of long.
- vtkCompositeLongLongArray
- composite implicit array of long long.
- vtkCompositeShortArray
- composite implicit array of short.
- vtkCompositeSignedCharArray
- composite implicit array of signed char.
- vtkCompositeUnsignedCharArray
- composite implicit array of unsigned char.
- vtkCompositeUnsignedIntArray
- composite implicit array of unsigned int.
- vtkCompositeUnsignedLongArray
- composite implicit array of unsigned long.
- vtkCompositeUnsignedLongLongArray
- composite implicit array of unsigned long long.
- vtkCompositeUnsignedShortArray
- composite implicit array of unsigned short.
- vtkConstantCharArray
- constant implicit array of char.
- vtkConstantDoubleArray
- constant implicit array of double.
- vtkConstantFloatArray
- constant implicit array of float.
- vtkConstantIdTypeArray
- constant implicit array of vtkIdType.
- vtkConstantIntArray
- constant implicit array of int.
- vtkConstantLongArray
- constant implicit array of long.
- vtkConstantLongLongArray
- constant implicit array of long long.
- vtkConstantShortArray
- constant implicit array of short.
- vtkConstantSignedCharArray
- constant implicit array of signed char.
- vtkConstantUnsignedCharArray
- constant implicit array of unsigned char.
- vtkConstantUnsignedIntArray
- constant implicit array of unsigned int.
- vtkConstantUnsignedLongArray
- constant implicit array of unsigned long.
- vtkConstantUnsignedLongLongArray
- constant implicit array of unsigned long long.
- vtkConstantUnsignedShortArray
- constant implicit array of unsigned short.
- vtkDataArrayCollection
- maintain an ordered list of dataarray objects
- vtkDataArrayCollectionIterator
- iterator through a vtkDataArrayCollection.
- vtkDataArraySelection
- Store on/off settings for data arrays, etc.
- vtkDebugLeaks
- identify memory leaks at program termination
- vtkDeserializer
- Deserialize VTK objects from JSON.
- vtkDoubleArray
- dynamic, self-adjusting array of double
- vtkDynamicLoader
- class interface to system dynamic libraries
- vtkEventDataDevice3D
- vtkEventDataForDevice
- vtkEventForwarderCommand
- a simple event forwarder command
- vtkFileOutputWindow
- File Specific output window class
- vtkFloatArray
- dynamic, self-adjusting array of float
- vtkGarbageCollector
- Detect and break reference loops
- vtkIdList
- list of point or cell ids
- vtkIdListCollection
- maintain an ordered list of IdList objects
- vtkIdTypeArray
- dynamic, self-adjusting array of vtkIdType
- vtkIndexedCharArray
- indexed implicit array of char.
- vtkIndexedDoubleArray
- indexed implicit array of double.
- vtkIndexedFloatArray
- indexed implicit array of float.
- vtkIndexedIdTypeArray
- indexed implicit array of vtkIdType.
- vtkIndexedIntArray
- indexed implicit array of int.
- vtkIndexedLongArray
- indexed implicit array of long.
- vtkIndexedLongLongArray
- indexed implicit array of long long.
- vtkIndexedShortArray
- indexed implicit array of short.
- vtkIndexedSignedCharArray
- indexed implicit array of signed char.
- vtkIndexedUnsignedCharArray
- indexed implicit array of unsigned char.
- vtkIndexedUnsignedIntArray
- indexed implicit array of unsigned int.
- vtkIndexedUnsignedLongArray
- indexed implicit array of unsigned long.
- vtkIndexedUnsignedLongLongArray
- indexed implicit array of unsigned long long.
- vtkIndexedUnsignedShortArray
- indexed implicit array of unsigned short.
- vtkInformation
- Store vtkAlgorithm input/output information.
- vtkInformationIterator
- Iterates over keys of an information object
- vtkInformationKeyLookup
- Find vtkInformationKeys from name and
- vtkInformationVector
- Store zero or more vtkInformation instances.
- vtkIntArray
- dynamic, self-adjusting array of int
- vtkLongArray
- dynamic, self-adjusting array of long
- vtkLongLongArray
- dynamic, self-adjusting array of long long
- vtkLookupTable
- map scalar values into colors via a lookup table
- vtkMarshalContext
- Shared context used by
vtkSerializer and vtkDeserializer - vtkMath
- performs common math operations
- vtkMersenneTwister
- Generator for Mersenne Twister pseudorandom numbers
- vtkMinimalStandardRandomSequence
- Park and Miller Sequence of pseudo random numbers
- vtkMultiThreader
- A class for performing multithreaded execution
- vtkObject
- abstract base class for most VTK objects
- vtkObjectFactoryCollection
- maintain a list of object factories
- vtkOldStyleCallbackCommand
- supports legacy function callbacks for VTK
- vtkOutputWindow
- base class for writing debug output to a console
- vtkOverrideInformationCollection
- maintain a list of override information objects
- vtkPoints
- represent and manipulate 3D points
- vtkPoints2D
- represent and manipulate 2D points
- vtkPriorityQueue
- a list of ids arranged in priority order
- vtkRandomPool
- convenience class to quickly generate a pool of random numbers
- vtkReferenceCount
- Obsolete / empty subclass of object.
- vtkScalarsToColors
- Superclass for mapping scalar values to colors
- vtkSerializer
- Serialize VTK objects to JSON.
- vtkShortArray
- dynamic, self-adjusting array of short
- vtkSignedCharArray
- dynamic, self-adjusting array of signed char
- vtkSortDataArray
- provides several methods for sorting VTK arrays.
- vtkStringArray
- a vtkAbstractArray subclass for strings
- vtkStringOutputWindow
- File Specific output window class
- vtkTimePointUtility
- performs common time operations
- vtkTypeFloat32Array
- vtkTypeFloat64Array
- vtkTypeInt8Array
- vtkTypeInt16Array
- vtkTypeInt32Array
- vtkTypeInt64Array
- vtkTypeUInt8Array
- vtkTypeUInt16Array
- vtkTypeUInt32Array
- vtkTypeUInt64Array
- vtkUnsignedCharArray
- dynamic, self-adjusting array of unsigned char
- vtkUnsignedIntArray
- dynamic, self-adjusting array of unsigned int
- vtkUnsignedLongArray
- dynamic, self-adjusting array of unsigned long
- vtkUnsignedLongLongArray
- dynamic, self-adjusting array of unsigned long long
- vtkUnsignedShortArray
- dynamic, self-adjusting array of unsigned short
- vtkVariantArray
- An array holding vtkVariants.
- vtkVersion
- Versioning class for vtk
- vtkVoidArray
- dynamic, self-adjusting array of void* pointers
- vtkWeakReference
- Utility class to hold a weak reference to a vtkObject.
- vtkXMLFileOutputWindow
- XML File Specific output window class