vtkAnimationCue

Struct vtkAnimationCue 

pub struct vtkAnimationCue(/* private fields */);
a seqin an animation.

vtkAnimationCue and vtkAnimationScene provide the framework to support animations in VTK. vtkAnimationCue represents an entity that changes/ animates with time, while vtkAnimationScene represents scene or setup for the animation, which consists on individual cues or other scenes.

A cue has three states: UNINITIALIZED, ACTIVE and INACTIVE. UNINITIALIZED represents an point in time before the start time of the cue. The cue is in ACTIVE state at a point in time between start time and end time for the cue. While, beyond the end time, it is in INACTIVE state. When the cue enters the ACTIVE state, StartAnimationCueEvent is fired. This event may be handled to initialize the entity to be animated. When the cue leaves the ACTIVE state, EndAnimationCueEvent is fired, which can be handled to cleanup after having run the animation. For every request to render during the ACTIVE state, AnimationCueTickEvent is fired, which must be handled to perform the actual animation. @sa vtkAnimationScene

Implementations

Source

impl vtkAnimationCue

pub fn new() -> Self

Creates a new vtkAnimationCue wrapped inside vtkNew