vtkArchiver

Struct vtkArchiver 

pub struct vtkArchiver(/* private fields */);
Writes an archive

vtkArchiver is a base class for constructing an archive. The default implementation constructs a directory at the location of the ArchiveName and populates it with files and directories as requested by Insert(). Classes that derive from vtkArchiver can customize the output using such features as compression, in-memory serialization and third-party archival tools.

Implementations

Source

impl vtkArchiver

pub fn new() -> Self

Creates a new vtkArchiver wrapped inside vtkNew