vtkBitArray

Struct vtkBitArray 

pub struct vtkBitArray(/* private fields */);
dynamic, self-adjusting array of bits

vtkBitArray is an array of bits (0/1 data value). The array is packed so that each byte stores eight bits. vtkBitArray provides methods for insertion and retrieval of bits, and will automatically resize itself to hold new data.

WARNING This class is not thread-safe during write access

Implementations

Source

impl vtkBitArray

pub fn new() -> Self

Creates a new vtkBitArray wrapped inside vtkNew