pub struct vtkBoxMuellerRandomSequence(/* private fields */);Expand description
Gaussian sequence of pseudo random numbers implemented with the Box-Mueller transform
vtkGaussianRandomSequence is a sequence of pseudo random numbers distributed according to the Gaussian/normal distribution (mean=0 and standard deviation=1).
It based is calculation from a uniformly distributed pseudo random sequence. The initial sequence is a vtkMinimalStandardRandomSequence.
Implementations
Sourceimpl vtkBoxMuellerRandomSequence
impl vtkBoxMuellerRandomSequence
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkBoxMuellerRandomSequence wrapped inside vtkNew