vtkByteSwap

Struct vtkByteSwap 

pub struct vtkByteSwap(/* private fields */);
perform machine dependent byte swapping

vtkByteSwap is used by other classes to perform machine dependent byte swapping. Byte swapping is often used when reading or writing binary files.

Implementations

Source

impl vtkByteSwap

pub fn new() -> Self

Creates a new vtkByteSwap wrapped inside vtkNew