vtkCallbackCommand

Struct vtkCallbackCommand 

pub struct vtkCallbackCommand(/* private fields */);
supports function callbacks

Use vtkCallbackCommand for generic function callbacks. That is, this class can be used when you wish to execute a function (of the signature described below) using the Command/Observer design pattern in VTK. The callback function should have the form

void func(vtkObject*, unsigned long eid, void* clientdata, void *calldata)

where the parameter vtkObject* is the object invoking the event; eid is the event id (see vtkCommand.h); clientdata is special data that should is associated with this instance of vtkCallbackCommand; and calldata is data that the vtkObject::InvokeEvent() may send with the callback. For example, the invocation of the ProgressEvent sends along the progress value as calldata.

@sa vtkCommand vtkOldStyleCallbackCommand

Implementations

Source

impl vtkCallbackCommand

pub fn new() -> Self

Creates a new vtkCallbackCommand wrapped inside vtkNew