pub struct vtkCollection(/* private fields */);Expand description
create and manipulate ordered lists of objects
vtkCollection is a general object for creating and manipulating lists of objects. The lists are ordered and allow duplicate entries. vtkCollection also serves as a base class for lists of specific types of objects.
@sa vtkActorCollection vtkAssemblyPaths vtkDataSetCollection vtkImplicitFunctionCollection vtkLightCollection vtkPolyDataCollection vtkRenderWindowCollection vtkRendererCollection vtkStructuredPointsCollection vtkTransformCollection vtkVolumeCollection
Implementations
Sourceimpl vtkCollection
impl vtkCollection
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCollection wrapped inside vtkNew