vtkCollectionIterator

Struct vtkCollectionIterator 

pub struct vtkCollectionIterator(/* private fields */);
iterator through a vtkCollection.

vtkCollectionIterator provides an alternative way to traverse through the objects in a vtkCollection. Unlike the collection’s built in interface, this allows multiple iterators to simultaneously traverse the collection. If items are removed from the collection, only the iterators currently pointing to those items are invalidated. Other iterators will still continue to function normally.

Implementations

Source

impl vtkCollectionIterator

pub fn new() -> Self

Creates a new vtkCollectionIterator wrapped inside vtkNew