vtkDoubleArray

Struct vtkDoubleArray 

pub struct vtkDoubleArray(/* private fields */);
dynamic, self-adjusting array of double

vtkDoubleArray is an array of values of type double. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.

Implementations

Source

impl vtkDoubleArray

pub fn new() -> Self

Creates a new vtkDoubleArray wrapped inside vtkNew