pub struct vtkEventForwarderCommand(/* private fields */);Expand description
a simple event forwarder command
Use vtkEventForwarderCommand to forward an event to a new object. This command will intercept the event, and use InvokeEvent on a ‘target’ as if that object was the one that invoked the event instead of the object this command was attached to using AddObserver.
@sa vtkCommand
Implementations
Sourceimpl vtkEventForwarderCommand
impl vtkEventForwarderCommand
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkEventForwarderCommand wrapped inside vtkNew