pub struct vtkFloatArray(/* private fields */);Expand description
dynamic, self-adjusting array of float
vtkFloatArray is an array of values of type float. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
Implementations
Sourceimpl vtkFloatArray
impl vtkFloatArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkFloatArray wrapped inside vtkNew