pub struct vtkIdList(/* private fields */);Expand description
list of point or cell ids
vtkIdList is used to represent and pass data id’s between objects. vtkIdList may represent any type of integer id, but usually represents point and cell ids.
Implementations