pub struct vtkInformation(/* private fields */);Expand description
Store vtkAlgorithm input/output information.
vtkInformation represents information and/or data for one input or one output of a vtkAlgorithm. It maps from keys to values of several data types. Instances of this class are collected in vtkInformationVector instances and passed to vtkAlgorithm::ProcessRequest calls. The information and data referenced by the instance on a particular input or output define the request made to the vtkAlgorithm instance.
Implementations
Sourceimpl vtkInformation
impl vtkInformation
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkInformation wrapped inside vtkNew