vtkInformationIterator

Struct vtkInformationIterator 

pub struct vtkInformationIterator(/* private fields */);
Iterates over keys of an information object

vtkInformationIterator can be used to iterate over the keys of an information object. The corresponding values can then be directly obtained from the information object using the keys.

@sa vtkInformation vtkInformationKey

Implementations

Source

impl vtkInformationIterator

pub fn new() -> Self

Creates a new vtkInformationIterator wrapped inside vtkNew