pub struct vtkInformationVector(/* private fields */);Expand description
Store zero or more vtkInformation instances.
vtkInformationVector stores a vector of zero or more vtkInformation objects corresponding to the input or output information for a vtkAlgorithm. An instance of this class is passed to vtkAlgorithm::ProcessRequest calls.
Implementations
Sourceimpl vtkInformationVector
impl vtkInformationVector
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkInformationVector wrapped inside vtkNew