pub struct vtkIntArray(/* private fields */);Expand description
dynamic, self-adjusting array of int
vtkIntArray is an array of values of type int. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
The C++ standard does not define the exact size of the int type, so use of this type directly is discouraged. If an array of 32 bit integers is needed, prefer vtkTypeInt32Array to this class.
Implementations
Sourceimpl vtkIntArray
impl vtkIntArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkIntArray wrapped inside vtkNew