vtkMarshalContext

Struct vtkMarshalContext 

pub struct vtkMarshalContext(/* private fields */);
Shared context used by vtkSerializer and vtkDeserializer

This class is capable of tracking dependencies among VTK objects, their states and preventing recursion when the VTK serialization classes are used.

It also provides centralized storage and tracking of objects in a weak object map, recording ownership of objects using a strong object map, hashing the contents of blobs to minimize data redundancies in the state and finally an API to coordinate the registration and removal of states, objects and blobs.

Implementations

Source

impl vtkMarshalContext

pub fn new() -> Self

Creates a new vtkMarshalContext wrapped inside vtkNew