vtkMinimalStandardRandomSequence

Struct vtkMinimalStandardRandomSequence 

pub struct vtkMinimalStandardRandomSequence(/* private fields */);
Park and Miller Sequence of pseudo random numbers

vtkMinimalStandardRandomSequence is a sequence of statistically independent pseudo random numbers uniformly distributed between 0.0 and 1.0.

The sequence is generated by a prime modulus multiplicative linear congruential generator (PMMLCG) or “Lehmer generator” with multiplier 16807 and prime modulus 2^(31)-1. The authors calls it “minimal standard random number generator”

ref: “Random Number Generators: Good Ones are Hard to Find,” by Stephen K. Park and Keith W. Miller in Communications of the ACM, 31, 10 (Oct. 1988) pp. 1192-1201. Code is at page 1195, “Integer version 2”

Correctness test is described in first column, page 1195: A seed of 1 at step 1 should give a seed of 1043618065 at step 10001.

Implementations

Source

impl vtkMinimalStandardRandomSequence

pub fn new() -> Self

Creates a new vtkMinimalStandardRandomSequence wrapped inside vtkNew