pub struct vtkMultiThreader(/* private fields */);Expand description
A class for performing multithreaded execution
vtkMultithreader is a class that provides support for multithreaded execution using pthreads on POSIX systems, or Win32 threads on Windows. This class can be used to execute a single method on multiple threads, or to specify a method per thread.
Implementations
Sourceimpl vtkMultiThreader
impl vtkMultiThreader
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMultiThreader wrapped inside vtkNew