vtkOldStyleCallbackCommand

Struct vtkOldStyleCallbackCommand 

pub struct vtkOldStyleCallbackCommand(/* private fields */);
supports legacy function callbacks for VTK

vtkOldStyleCallbackCommand is a callback that supports the legacy callback methods found in VTK. For example, the legacy method vtkProcessObject::SetStartMethod() is actually invoked using the command/observer design pattern of VTK, and the vtkOldStyleCallbackCommand is used to provide the legacy functionality. The callback function should have the form void func(void *clientdata), where clientdata is special data that should is associated with this instance of vtkCallbackCommand.

@warning This is legacy glue. Please do not use; it will be eventually eliminated.

@sa vtkCommand vtkCallbackCommand

Implementations

Source

impl vtkOldStyleCallbackCommand

pub fn new() -> Self

Creates a new vtkOldStyleCallbackCommand wrapped inside vtkNew