vtkShortArray

Struct vtkShortArray 

pub struct vtkShortArray(/* private fields */);
dynamic, self-adjusting array of short

vtkShortArray is an array of values of type short. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.

The C++ standard does not define the exact size of the short type, so use of this type directly is discouraged. If an array of 16 bit integers is needed, prefer vtkTypeInt16Array to this class.

Implementations

Source

impl vtkShortArray

pub fn new() -> Self

Creates a new vtkShortArray wrapped inside vtkNew