pub struct vtkStringOutputWindow(/* private fields */);Expand description
File Specific output window class
Writes debug/warning/error output to a log file instead of the console. To use this class, instantiate it and then call SetInstance(this).
Implementations
Sourceimpl vtkStringOutputWindow
impl vtkStringOutputWindow
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkStringOutputWindow wrapped inside vtkNew