pub struct vtkUnsignedCharArray(/* private fields */);Expand description
dynamic, self-adjusting array of unsigned char
vtkUnsignedCharArray is an array of values of type unsigned char. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
Implementations
Sourceimpl vtkUnsignedCharArray
impl vtkUnsignedCharArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUnsignedCharArray wrapped inside vtkNew