vtkUnsignedIntArray

Struct vtkUnsignedIntArray 

pub struct vtkUnsignedIntArray(/* private fields */);
dynamic, self-adjusting array of unsigned int

vtkUnsignedIntArray is an array of values of type unsigned int. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.

The C++ standard does not define the exact size of the unsigned int type, so use of this type directly is discouraged. If an array of 32 bit unsigned integers is needed, prefer vtkTypeUInt32Array to this class.

Implementations

Source

impl vtkUnsignedIntArray

pub fn new() -> Self

Creates a new vtkUnsignedIntArray wrapped inside vtkNew