vtkUnsignedLongLongArray

Struct vtkUnsignedLongLongArray 

pub struct vtkUnsignedLongLongArray(/* private fields */);
dynamic, self-adjusting array of unsigned long long

vtkUnsignedLongLongArray is an array of values of type unsigned long long. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.

This class should not be used directly, as it only exists on systems where the unsigned long long type is defined. If you need an unsigned 64 bit integer data array, use vtkTypeUInt64Array instead.

Implementations

Source

impl vtkUnsignedLongLongArray

pub fn new() -> Self

Creates a new vtkUnsignedLongLongArray wrapped inside vtkNew