pub struct vtkUnsignedShortArray(/* private fields */);Expand description
dynamic, self-adjusting array of unsigned short
vtkUnsignedShortArray is an array of values of type unsigned short. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
The C++ standard does not define the exact size of the unsigned short type, so use of this type directly is discouraged. If an array of 16 bit unsigned integers is needed, prefer vtkTypeUInt16Array to this class.
Implementations
Sourceimpl vtkUnsignedShortArray
impl vtkUnsignedShortArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUnsignedShortArray wrapped inside vtkNew