pub struct vtkVariantArray(/* private fields */);Expand description
An array holding vtkVariants.
@par Thanks: Thanks to Patricia Crossno, Ken Moreland, Andrew Wilson and Brian Wylie from Sandia National Laboratories for their help in developing this class.
Implementations
Sourceimpl vtkVariantArray
impl vtkVariantArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkVariantArray wrapped inside vtkNew