vtkVoidArray

Struct vtkVoidArray 

pub struct vtkVoidArray(/* private fields */);
dynamic, self-adjusting array of void* pointers

vtkVoidArray is an array of pointers to void. It provides methods for insertion and retrieval of these pointers values, and will automatically resize itself to hold new data.

Implementations

Source

impl vtkVoidArray

pub fn new() -> Self

Creates a new vtkVoidArray wrapped inside vtkNew