pub struct vtkWeakReference(/* private fields */);Expand description
Utility class to hold a weak reference to a vtkObject.
Simple Set(…)/Get(…) interface. Used in numpy support to provide a reference to a vtkObject without preventing it from being collected.
Implementations
Sourceimpl vtkWeakReference
impl vtkWeakReference
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkWeakReference wrapped inside vtkNew