pub struct vtkAdjacentVertexIterator(/* private fields */);Expand description
Iterates through adjacent vertices in a graph.
vtkAdjacentVertexIterator iterates through all vertices adjacent to a vertex, i.e. the vertices which may be reached by traversing an out edge of the source vertex. Use graph->GetAdjacentVertices(v, it) to initialize the iterator.
Implementations
Sourceimpl vtkAdjacentVertexIterator
impl vtkAdjacentVertexIterator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkAdjacentVertexIterator wrapped inside vtkNew