pub struct vtkAnimationScene(/* private fields */);Expand description
the animation scene manager.
vtkAnimationCue and vtkAnimationScene provide the framework to support animations in VTK. vtkAnimationCue represents an entity that changes/ animates with time, while vtkAnimationScene represents scene or setup for the animation, which consists of individual cues or other scenes.
A scene can be played in real time mode, or as a sequence of frames 1/frame rate apart in time. @sa vtkAnimationCue
Implementations
Sourceimpl vtkAnimationScene
impl vtkAnimationScene
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkAnimationScene wrapped inside vtkNew