pub struct vtkAnnotation(/* private fields */);Expand description
Stores a collection of annotation artifacts.
vtkAnnotation is a collection of annotation properties along with an associated selection indicating the portion of data the annotation refers to.
@par Thanks: Timothy M. Shead (tshead@sandia.gov) at Sandia National Laboratories contributed code to this class.
Implementations
Sourceimpl vtkAnnotation
impl vtkAnnotation
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkAnnotation wrapped inside vtkNew