pub struct vtkAnnotationLayers(/* private fields */);Expand description
Stores a ordered collection of annotation sets
vtkAnnotationLayers stores a vector of annotation layers. Each layer may contain any number of vtkAnnotation objects. The ordering of the layers introduces a prioritization of annotations. Annotations in higher layers may obscure annotations in lower layers.
Implementations
Sourceimpl vtkAnnotationLayers
impl vtkAnnotationLayers
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkAnnotationLayers wrapped inside vtkNew