pub struct vtkArrayData(/* private fields */);Expand description
Pipeline data object that contains multiple vtkArray objects.
Because vtkArray cannot be stored as attributes of data objects (yet), a “carrier” object is needed to pass vtkArray through the pipeline. vtkArrayData acts as a container of zero-to-many vtkArray instances, which can be retrieved via a zero-based index. Note that a collection of arrays stored in vtkArrayData may-or-may-not have related types, dimensions, or extents.
@sa vtkArrayDataAlgorithm, vtkArray
@par Thanks: Developed by Timothy M. Shead (tshead@sandia.gov) at Sandia National Laboratories.
Implementations
Sourceimpl vtkArrayData
impl vtkArrayData
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkArrayData wrapped inside vtkNew