vtkBSPIntersections

Struct vtkBSPIntersections 

pub struct vtkBSPIntersections(/* private fields */);
Perform calculations (mostly intersection

calculations) on regions of a 3D binary spatial partitioning.

Given an axis aligned binary spatial partitioning described by a vtkBSPCuts object, perform intersection queries on various geometric entities with regions of the spatial partitioning.

@sa vtkBSPCuts vtkKdTree

Implementations

Source

impl vtkBSPIntersections

pub fn new() -> Self

Creates a new vtkBSPIntersections wrapped inside vtkNew