pub struct vtkBiQuadraticQuad(/* private fields */);Expand description
cell represents a parabolic, 9-node
isoparametric quad
vtkQuadraticQuad is a concrete implementation of vtkNonLinearCell to represent a two-dimensional, 9-node isoparametric parabolic quadrilateral element with a Centerpoint. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node for each of the four edges of the cell and a center node at the surface. The ordering of the eight points defining the cell are point ids (0-3,4-8) where ids 0-3 define the four corner vertices of the quad; ids 4-7 define the midedge nodes (0,1), (1,2), (2,3), (3,0) and 8 define the face center node.
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticWedge vtkQuadraticPyramid vtkQuadraticQuad
@par Thanks: Thanks to Soeren Gebbert who developed this class and integrated it into VTK 5.0.
Implementations
Sourceimpl vtkBiQuadraticQuad
impl vtkBiQuadraticQuad
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkBiQuadraticQuad wrapped inside vtkNew