pub struct vtkBox(/* private fields */);Expand description
implicit function for a bounding box
vtkBox computes the implicit function and/or gradient for a axis-aligned bounding box. (The superclasses transform can be used to modify this orientation.) Each side of the box is orthogonal to all other sides meeting along shared edges and all faces are orthogonal to the x-y-z coordinate axes. (If you wish to orient this box differently, recall that the superclass vtkImplicitFunction supports a transformation matrix.) vtkBox is a concrete implementation of vtkImplicitFunction.
@sa vtkCubeSource vtkImplicitFunction vtkBoundingBox
Implementations