pub struct vtkCellAttribute(/* private fields */);Expand description
A function defined over the physical domain of a vtkCellGrid.
This is a base class for attributes (functions) defined on the space discretized by a vtkCellGrid. A vtkCellAttribute class must handle cells of all types present in the grid.
@sa vtkCellGrid
Implementations
Sourceimpl vtkCellAttribute
impl vtkCellAttribute
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellAttribute wrapped inside vtkNew