pub struct vtkCellAttributeCalculator(/* private fields */);Expand description
Perform a per-cell calculation on a vtkCellAttribute.
This empty class serves as a common base class for calculators that compute quantities based on cell-attribute data.
Examples of calculators include
- computing interpolated values;
- computing spatial derivatives (such as the Jacobian or Hessian matrices); or
- computing integrals over an entire cell.
Each type of calculator provides its own abstract subclass with virtual methods and then per-cell-type, per-attribute-type concrete implementations.
@sa vtkCellGridAttribute
Implementations
Sourceimpl vtkCellAttributeCalculator
impl vtkCellAttributeCalculator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellAttributeCalculator wrapped inside vtkNew