vtkCellData

Struct vtkCellData 

pub struct vtkCellData(/* private fields */);
represent and manipulate cell attribute data

vtkCellData is a class that is used to represent and manipulate cell attribute data (e.g., scalars, vectors, normals, texture coordinates, etc.) Special methods are provided to work with filter objects, such as passing data through filter, copying data from one cell to another, and interpolating data given cell interpolation weights.

By default, GhostTypesToSkip is set to DUPLICATECELL | HIDDENCELL | REFINEDCELL. See vtkDataSetAttributes for the definition of those constants.

Implementations

Source

impl vtkCellData

pub fn new() -> Self

Creates a new vtkCellData wrapped inside vtkNew