pub struct vtkCellGridRangeQuery(/* private fields */);Expand description
Compute the range of a component of some vtkCellAttribute.
If \a FiniteRange is true, then the range will omit any NaN or ±Inf values present in the data. Otherwise (the default), the range may contain these exceptional values.
If \a Component is
- -2 (the default), the range of L₂-norms is computed.
- -1, the range of L₁-norms is computed.
- out of bounds, then an invalid range will be returned ([1, 0]).
Note that this query is intended to be run by vtkCellGrid::GetRange() since the cell-grid holds a cache of ranges. You may run it outside of this method, but that may cause unnecessary re-computation of ranges.
Implementations
Sourceimpl vtkCellGridRangeQuery
impl vtkCellGridRangeQuery
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellGridRangeQuery wrapped inside vtkNew