pub struct vtkCellGridSidesCache(/* private fields */);Expand description
Hold a map from hash-ids (representing sides of cells of multiple types)
to details on the cells that claim the corresponding side.
This class is created by filters such as vtkCellGridComputeSides and vtkCellGridExtractCrinkle; it can be re-used by the same filter and any others that process the same input (since it is stored in a cache available to them).
Implementations
Sourceimpl vtkCellGridSidesCache
impl vtkCellGridSidesCache
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellGridSidesCache wrapped inside vtkNew