vtkCellGridSidesQuery

Struct vtkCellGridSidesQuery 

pub struct vtkCellGridSidesQuery(/* private fields */);
\brief A cell-grid query for enumerating sides of cells.

This query runs in 3 passes (see vtkCellGridSidesQuery::PassWork):

  • In the first pass, responders invoke the AddSides() method on this query, entries are added to this->Hashes storage indicating the cells which are bounded by a given shape + connectivity.
  • In the second pass, responders mark the entries created above and add entries in this->Sides. This reorganizes the hashes into groups more amenable to output as side arrays. This pass is called “Summarization,” since not every input side identified will be output.
  • In the third and final pass, responders create new cells in the output cell-grid that correspond to the selected sides of the input.

Implementations

Source

impl vtkCellGridSidesQuery

pub fn new() -> Self

Creates a new vtkCellGridSidesQuery wrapped inside vtkNew