vtkCellLinks

Struct vtkCellLinks 

pub struct vtkCellLinks(/* private fields */);
object represents upward pointers from points to list of cells using each point

vtkCellLinks is a supplemental object to vtkCellArray and vtkCellTypes, enabling access from points to the cells using the points. vtkCellLinks is a list of cell ids, each such link representing a dynamic list of cell ids using the point. The information provided by this object can be used to determine neighbors and construct other local topological information.

@warning vtkCellLinks supports incremental (i.e., “editable”) operations such as inserting a new cell, or deleting a point. Because of this, it is less memory efficient, and slower to construct and delete than static classes such as vtkStaticCellLinks or vtkStaticCellLinksTemplate. However these other classes are typically meant for one-time (static) construction.

@sa vtkCellArray vtkCellTypes vtkStaticCellLinks vtkStaticCellLinksTemplate

Implementations

pub fn new() -> Self

Creates a new vtkCellLinks wrapped inside vtkNew