vtkCellLocator

Struct vtkCellLocator 

pub struct vtkCellLocator(/* private fields */);
octree-based spatial search object to quickly locate cells

vtkCellLocator is a spatial search object to quickly locate cells in 3D. vtkCellLocator uses a uniform-level octree subdivision, where each octant (an octant is also referred to as a bucket) carries an indication of whether it is empty or not, and each leaf octant carries a list of the cells inside of it. (An octant is not empty if it has one or more cells inside of it.) Typical operations are intersection with a line to return candidate cells, or intersection with another vtkCellLocator to return candidate cells.

@warning vtkCellLocator utilizes the following parent class parameters:

  • Automatic (default true)
  • Level (default 8)
  • MaxLevel (default 8)
  • NumberOfCellsPerNode (default 25)
  • CacheCellBounds (default true)
  • UseExistingSearchStructure (default false)

vtkCellLocator does NOT utilize the following parameters:

  • Tolerance
  • RetainCellLists

@sa vtkAbstractCellLocator vtkStaticCellLocator vtkCellTreeLocator vtkModifiedBSPTree vtkOBBTree

Implementations

Source

impl vtkCellLocator

pub fn new() -> Self

Creates a new vtkCellLocator wrapped inside vtkNew