vtkCellTreeLocator

Struct vtkCellTreeLocator 

pub struct vtkCellTreeLocator(/* private fields */);
This class implements the data structures, construction

algorithms for fast cell location.

Cell Tree is a bounding interval hierarchy based data structure, where child boxes do not form an exact split of the parent boxes along a dimension. Therefore two axis- aligned bounding planes (left max and right min) are stored for each node along a dimension. This class implements the data structure (Cell Tree Node) and its build and traversal algorithms described in the paper. Some methods in building and traversing the cell tree in this class were derived from avtCellLocatorBIH class in the VisIT Visualization Tool.

vtkCellTreeLocator utilizes the following parent class parameters:

  • NumberOfCellsPerNode (default 8)
  • CacheCellBounds (default true)
  • UseExistingSearchStructure (default false)

vtkCellTreeLocator does NOT utilize the following parameters:

  • Automatic
  • Level
  • MaxLevel
  • Tolerance
  • RetainCellLists

@warning This class is templated. It may run slower than serial execution if the code is not optimized during compilation. Build in Release or ReleaseWithDebugInfo.

From the article: “Fast, Memory-Efficient Cell location in Unstructured Grids for Visualization” by Christoph Garth and Kenneth I. Joy in VisWeek, 2011.

@sa vtkAbstractCellLocator vtkCellLocator vtkStaticCellLocator vtkModifiedBSPTree vtkOBBTree

Implementations

Source

impl vtkCellTreeLocator

pub fn new() -> Self

Creates a new vtkCellTreeLocator wrapped inside vtkNew