pub struct vtkClosestPointStrategy(/* private fields */);Expand description
implement a specific vtkPointSet::FindCell() strategy based
on closest point
vtkClosestPointStrategy is implements a FindCell() strategy based on locating the closest point in a dataset, and then searching the attached cells. While relatively fast, it does not always return the correct result (it may not find a cell, since the closest cell may not be connected to the closest point). vtkCellLocatorStrategy or vtkClosestNPointsStrategy will produce better results at the cost of speed.
@sa vtkFindCellStrategy vtkPointSet vtkCellLocatorStrategy vtkClosestNPointsStrategy
Implementations
Sourceimpl vtkClosestPointStrategy
impl vtkClosestPointStrategy
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkClosestPointStrategy wrapped inside vtkNew