pub struct vtkConvexPointSet(/* private fields */);Expand description
a 3D cell defined by a set of convex points
vtkConvexPointSet is a concrete implementation that represents a 3D cell defined by a convex set of points. An example of such a cell is an octant (from an octree). vtkConvexPointSet uses the ordered triangulations approach (vtkOrderedTriangulator) to create triangulations guaranteed to be compatible across shared faces. This allows a general approach to processing complex, convex cell types.
@sa vtkHexahedron vtkPyramid vtkTetra vtkVoxel vtkWedge
Implementations
Sourceimpl vtkConvexPointSet
impl vtkConvexPointSet
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkConvexPointSet wrapped inside vtkNew