pub struct vtkCubicLine(/* private fields */);Expand description
cell represents a cubic , isoparametric 1D line
vtkCubicLine is a concrete implementation of vtkNonLinearCell to represent a 1D Cubic line. The Cubic Line is the 4 nodes isoparametric parabolic line . The interpolation is the standard finite element, cubic isoparametric shape function. The cell includes two mid-edge nodes. The ordering of the four points defining the cell is point ids (0,1,2,3) where id #2 and #3 are the mid-edge nodes. Please note that the parametric coordinates lie between -1 and 1 in accordance with most standard documentations. @par Thanks: \verbatim This file has been developed by Oxalya - www.oxalya.com \endverbatim
Implementations
Sourceimpl vtkCubicLine
impl vtkCubicLine
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCubicLine wrapped inside vtkNew