vtkCylinder

Struct vtkCylinder 

pub struct vtkCylinder(/* private fields */);
implicit function for a cylinder

vtkCylinder computes the implicit function and function gradient for a cylinder using F(r)=r^2-Radius^2. vtkCylinder is a concrete implementation of vtkImplicitFunction. By default the Cylinder is centered at the origin and the axis of rotation is along the y-axis. You can redefine the center and axis of rotation by setting the Center and Axis data members. (Note that it is also possible to use the superclass’ vtkImplicitFunction transformation matrix if necessary to reposition by using FunctionValue() and FunctionGradient().)

@warning The cylinder is infinite in extent. To truncate the cylinder in modeling operations use the vtkImplicitBoolean in combination with clipping planes.

@sa vtkCylinderSource

Implementations

Source

impl vtkCylinder

pub fn new() -> Self

Creates a new vtkCylinder wrapped inside vtkNew