vtkDataObject

Struct vtkDataObject 

pub struct vtkDataObject(/* private fields */);
general representation of visualization data

vtkDataObject is an general representation of visualization data. It serves to encapsulate instance variables and methods for visualization network execution, as well as representing data consisting of a field (i.e., just an unstructured pile of data). This is to be compared with a vtkDataSet, which is data with geometric and/or topological structure.

vtkDataObjects are used to represent arbitrary repositories of data via the vtkFieldData instance variable. These data must be eventually mapped into a concrete subclass of vtkDataSet before they can actually be displayed.

@sa vtkDataSet vtkFieldData vtkDataObjectToDataSetFilter vtkFieldDataToAttributeDataFilter

Implementations

Source

impl vtkDataObject

pub fn new() -> Self

Creates a new vtkDataObject wrapped inside vtkNew