vtkDataSetAttributes

Struct vtkDataSetAttributes 

pub struct vtkDataSetAttributes(/* private fields */);
represent and manipulate attribute data in a dataset

vtkDataSetAttributes is a class that is used to represent and manipulate attribute data (e.g., scalars, vectors, normals, texture coordinates, tensors, global ids, pedigree ids, and field data).

This adds to vtkFieldData the ability to pick one of the arrays from the field as the currently active array for each attribute type. In other words, you pick one array to be called “THE” Scalars, and then filters down the pipeline will treat that array specially. For example vtkContourFilter will contour “THE” Scalar array unless a different array is asked for.

Additionally vtkDataSetAttributes provides methods that filters call to pass data through, copy data into, and interpolate from Fields. PassData passes entire arrays from the source to the destination. Copy passes through some subset of the tuples from the source to the destination. Interpolate interpolates from the chosen tuple(s) in the source data, using the provided weights, to produce new tuples in the destination. Each attribute type has pass, copy and interpolate “copy” flags that can be set in the destination to choose which attribute arrays will be transferred from the source to the destination.

Finally this class provides a mechanism to determine which attributes a group of sources have in common, and to copy tuples from a source into the destination, for only those attributes that are held by all.

@warning vtkDataSetAttributes is not in general thread safe due to the use of its vtkFieldData::BasicIterator RequiredArrays data member. The class vtkArrayListTemplate augments vtkDataSetAttributes for thread safety.

@sa vtkArrayListTemplate

Implementations

Source

impl vtkDataSetAttributes

pub fn new() -> Self

Creates a new vtkDataSetAttributes wrapped inside vtkNew