pub struct vtkDirectedGraph(/* private fields */);Expand description
A directed graph.
vtkDirectedGraph is a collection of vertices along with a collection of directed edges (edges that have a source and target). ShallowCopy() and DeepCopy() (and CheckedShallowCopy(), CheckedDeepCopy()) accept instances of vtkTree and vtkMutableDirectedGraph.
vtkDirectedGraph is read-only. To create an undirected graph, use an instance of vtkMutableDirectedGraph, then you may set the structure to a vtkDirectedGraph using ShallowCopy().
@sa vtkGraph vtkMutableDirectedGraph
Implementations
Sourceimpl vtkDirectedGraph
impl vtkDirectedGraph
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkDirectedGraph wrapped inside vtkNew