pub struct vtkExtractStructuredGridHelper(/* private fields */);Expand description
helper for extracting/sub-sampling
structured datasets.
vtkExtractStructuredGridHelper provides some common functionality that is used by filters that extract and sub-sample structured data. Specifically, it provides functionality for calculating the mapping from the output extent of each process to the input extent.
@sa vtkExtractGrid vtkExtractVOI vtkExtractRectilinearGrid
Implementations
Sourceimpl vtkExtractStructuredGridHelper
impl vtkExtractStructuredGridHelper
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkExtractStructuredGridHelper wrapped inside vtkNew