pub struct vtkGenericCell(/* private fields */);Expand description
provides thread-safe access to cells
vtkGenericCell is a class that provides access to concrete types of cells. It’s main purpose is to allow thread-safe access to cells, supporting the vtkDataSet::GetCell(vtkGenericCell *) method. vtkGenericCell acts like any type of cell, it just dereferences an internal representation. The SetCellType() methods use #define constants; these are defined in the file vtkCellType.h.
@sa vtkCell vtkDataSet
Implementations
Sourceimpl vtkGenericCell
impl vtkGenericCell
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkGenericCell wrapped inside vtkNew