pub struct vtkGeometricErrorMetric(/* private fields */);Expand description
Objects that compute
geometry-based error during cell tessellation.
It is a concrete error metric, based on a geometric criterium: the variation of the edge from a straight line.
@sa vtkGenericCellTessellator vtkGenericSubdivisionErrorMetric
Implementations
Sourceimpl vtkGeometricErrorMetric
impl vtkGeometricErrorMetric
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkGeometricErrorMetric wrapped inside vtkNew