pub struct vtkGraphEdge(/* private fields */);Expand description
Representation of a single graph edge.
A heavy-weight (vtkObject subclass) graph edge object that may be used instead of the vtkEdgeType struct, for use with wrappers. The edge contains the source and target vertex ids, and the edge id.
@sa vtkGraph
Implementations
Sourceimpl vtkGraphEdge
impl vtkGraphEdge
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkGraphEdge wrapped inside vtkNew