pub struct vtkHyperTreeGrid(/* private fields */);Expand description
A dataset containing a grid of vtkHyperTree instances
arranged as a rectilinear grid.
An hypertree grid is a dataset containing a rectilinear grid of root nodes, each of which can be refined as a vtkHyperTree grid. This organization of the root nodes allows for the definition of tree-based AMR grids that do not have uniform geometry. Some filters can be applied on this dataset: contour, outline, geometry.
The order and number of points must match that specified by the dimensions of the grid. The point order increases in i fastest (from 0<=i<dims[0]), then j (0<=j<dims[1]), then k (0<=k<dims[2]) where dims[] are the dimensions of the grid in the i-j-k topological directions. The number of points is dims[0]dims[1]dims[2]. The same is true for the cells of the grid. The order and number of cells must match that specified by the dimensions of the grid. The cell order increases in i fastest (from 0<=i<(dims[0]-1)), then j (0<=j<(dims[1]-1)), then k (0<=k<(dims[2]-1)) The number of cells is (dims[0]-1)(dims[1]-1)(dims[2]-1).
Dimensions : number of points by direction of rectilinear grid CellDims : number of cells by directions of rectilinear grid (1 for each dimensions 1)
@warning It is not a spatial search object. If you are looking for this kind of octree see vtkCellLocator instead. Extent support is not finished yet.
@sa vtkHyperTree vtkRectilinearGrid
@par Thanks: This class was written by Philippe Pebay, Joachim Pouderoux, and Charles Law, Kitware 2013 This class was modified by Guenole Harel and Jacques-Bernard Lekien 2014 This class was rewritten by Philippe Pebay, 2016 This class was modified by Jacques-Bernard Lekien 2018 This work was supported by Commissariat a l’Energie Atomique CEA, DAM, DIF, F-91297 Arpajon, France.
Implementations
Sourceimpl vtkHyperTreeGrid
impl vtkHyperTreeGrid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkHyperTreeGrid wrapped inside vtkNew