vtkHyperTreeGridOrientedCursor

Struct vtkHyperTreeGridOrientedCursor 

pub struct vtkHyperTreeGridOrientedCursor(/* private fields */);
Objects for traversal a HyperTreeGrid.

Objects that can perform depth traversal of a hyper tree grid, take into account more parameters (related to the grid structure) than the compact hyper tree cursor implemented in vtkHyperTree can. This is an abstract class. Cursors are created by the HyperTreeGrid implementation.

oriented cursors are used for simple recursive DFS. A cursor has no knowledge of its parent, only its children.

@sa vtkHyperTree vtkHyperTreeGrid

@par Thanks: This class was written by Guenole Harel and Jacques-Bernard Lekien, 2014. This class was re-written by Philippe Pebay, 2016. This class was re-written for more optimisation by Jacques-Bernard Lekien, Guenole Harel and Jerome Dubois, 2018. This work was supported by Commissariat a l’Energie Atomique CEA, DAM, DIF, F-91297 Arpajon, France.

Implementations

Source

impl vtkHyperTreeGridOrientedCursor

pub fn new() -> Self

Creates a new vtkHyperTreeGridOrientedCursor wrapped inside vtkNew