vtkImageData

Struct vtkImageData 

pub struct vtkImageData(/* private fields */);
topologically and geometrically regular array of data

vtkImageData is a data object that is a concrete implementation of vtkDataSet. vtkImageData represents a geometric structure that is a topological and geometrical regular array of points. Examples include volumes (voxel data) and pixmaps. This representation supports images up to three dimensions. The image may also be oriented (see the DirectionMatrices and related transformation methods). Note however, that not all filters support oriented images.

@sa vtkImageTransform

Implementations

Source

impl vtkImageData

pub fn new() -> Self

Creates a new vtkImageData wrapped inside vtkNew