vtkImplicitBoolean

Struct vtkImplicitBoolean 

pub struct vtkImplicitBoolean(/* private fields */);
implicit function consisting of boolean combinations of implicit functions

vtkImplicitBoolean is an implicit function consisting of boolean combinations of implicit functions. The class has a list of functions (FunctionList) that are combined according to a specified operator (VTK_UNION or VTK_INTERSECTION or VTK_DIFFERENCE). You can use nested combinations of vtkImplicitFunction’s (and/or vtkImplicitBoolean) to create elaborate implicit functions. vtkImplicitBoolean is a concrete implementation of vtkImplicitFunction.

The operators work as follows. The VTK_UNION operator takes the minimum value of all implicit functions. The VTK_INTERSECTION operator takes the maximum value of all implicit functions. The VTK_DIFFERENCE operator subtracts the 2nd through last implicit functions from the first. The VTK_UNION_OF_MAGNITUDES takes the minimum absolute value of the implicit functions.

Implementations

Source

impl vtkImplicitBoolean

pub fn new() -> Self

Creates a new vtkImplicitBoolean wrapped inside vtkNew