pub struct vtkImplicitHalo(/* private fields */);Expand description
implicit function for an halo
vtkImplicitHalo evaluates to 1.0 for each position in the sphere of a given center and radius Radius*(1-FadeOut). It evaluates to 0.0 for each position out the sphere of a given Center and radius Radius. It fades out linearly from 1.0 to 0.0 for points in a radius from Radius*(1-FadeOut) to Radius. vtkImplicitHalo is a concrete implementation of vtkImplicitFunction. It is useful as an input to vtkSampleFunction to generate an 2D image of an halo. It is used this way by vtkShadowMapPass. @warning It does not implement the gradient.
Implementations
Sourceimpl vtkImplicitHalo
impl vtkImplicitHalo
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkImplicitHalo wrapped inside vtkNew