vtkImplicitSelectionLoop

Struct vtkImplicitSelectionLoop 

pub struct vtkImplicitSelectionLoop(/* private fields */);
implicit function for a selection loop

vtkImplicitSelectionLoop computes the implicit function value and function gradient for an irregular, cylinder-like object whose cross section is defined by a set of points forming a loop. The loop need not be convex nor its points coplanar. However, the loop must be non-self-intersecting when projected onto the plane defined by the accumulated cross product around the loop (i.e., the axis of the loop). (Alternatively, you can specify the normal to use.)

The following procedure is used to compute the implicit function value for a point x. Each point of the loop is first projected onto the plane defined by the loop normal. This forms a polygon. Then, to evaluate the implicit function value, inside/outside tests are used to determine if x is inside the polygon, and the distance to the loop boundary is computed (negative values are inside the loop).

One example application of this implicit function class is to draw a loop on the surface of a mesh, and use the loop to clip or extract cells from within the loop. Remember, the selection loop is “infinite” in length, you can use a plane (in boolean combination) to cap the extent of the selection loop. Another trick is to use a connectivity filter to extract the closest region to a given point (i.e., one of the points used to define the selection loop).

@sa vtkImplicitFunction vtkImplicitBoolean vtkExtractGeometry vtkClipPolyData vtkConnectivityFilter vtkPolyDataConnectivityFilter

Implementations

Source

impl vtkImplicitSelectionLoop

pub fn new() -> Self

Creates a new vtkImplicitSelectionLoop wrapped inside vtkNew