vtkImplicitSum

Struct vtkImplicitSum 

pub struct vtkImplicitSum(/* private fields */);
implicit sum of other implicit functions

vtkImplicitSum produces a linear combination of other implicit functions. The contribution of each function is weighted by a scalar coefficient. The NormalizeByWeight option normalizes the output so that the scalar weights add up to 1. Note that this function gives accurate sums and gradients only if the input functions are linear.

Implementations

Source

impl vtkImplicitSum

pub fn new() -> Self

Creates a new vtkImplicitSum wrapped inside vtkNew