pub struct vtkKdNode(/* private fields */);Expand description
This class represents a single spatial region
in an 3D axis aligned binary spatial partitioning. It is assumed the region bounds some set of points. Regions are represented as nodes in a binary tree.
@sa vtkKdTree vtkOBSPCuts
Implementations