pub struct vtkLagrangeHexahedron(/* private fields */);Expand description
A 3D cell that represents an arbitrary order Lagrange hex
vtkLagrangeHexahedron is a concrete implementation of vtkCell to represent a 3D hexahedron using Lagrange shape functions of user specified order.
@sa vtkHexahedron
Implementations
Sourceimpl vtkLagrangeHexahedron
impl vtkLagrangeHexahedron
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkLagrangeHexahedron wrapped inside vtkNew