vtkMeanValueCoordinatesInterpolator

Struct vtkMeanValueCoordinatesInterpolator 

pub struct vtkMeanValueCoordinatesInterpolator(/* private fields */);
compute interpolation computes

for closed triangular mesh

vtkMeanValueCoordinatesInterpolator computes interpolation weights for a closed, manifold polyhedron mesh. Once computed, the interpolation weights can be used to interpolate data anywhere interior or exterior to the mesh. This work implements two MVC algorithms. The first one is for triangular meshes which is documented in the Siggraph 2005 paper by Tao Ju, Scot Schaefer and Joe Warren from Rice University “Mean Value Coordinates for Closed Triangular Meshes”. The second one is for general polyhedron mesh which is documented in the Eurographics Symposium on Geometry Processing 2006 paper by Torsten Langer, Alexander Belyaev and Hans-Peter Seidel from MPI Informatik “Spherical Barycentric Coordinates”. The filter will automatically choose which algorithm to use based on whether the input mesh is triangulated or not.

In VTK this class was initially created to interpolate data across polyhedral cells. In addition, the class can be used to interpolate data values from a polyhedron mesh, and to smoothly deform a mesh from an associated control mesh.

@sa vtkPolyhedralCell

Implementations

Source

impl vtkMeanValueCoordinatesInterpolator

pub fn new() -> Self

Creates a new vtkMeanValueCoordinatesInterpolator wrapped inside vtkNew