pub struct vtkMergePoints(/* private fields */);Expand description
merge exactly coincident points
vtkMergePoints is a locator object to quickly locate points in 3D. The primary difference between vtkMergePoints and its superclass vtkPointLocator is that vtkMergePoints merges precisely coincident points and is therefore much faster. @sa vtkCleanPolyData
Implementations
Sourceimpl vtkMergePoints
impl vtkMergePoints
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMergePoints wrapped inside vtkNew