pub struct vtkMultiPieceDataSet(/* private fields */);Expand description
composite dataset to encapsulates pieces of
dataset.
A vtkMultiPieceDataSet dataset groups multiple data pieces together. For example, say that a simulation broke a volume into 16 piece so that each piece can be processed with 1 process in parallel. We want to load this volume in a visualization cluster of 4 nodes. Each node will get 4 pieces, not necessarily forming a whole rectangular piece. In this case, it is not possible to append the 4 pieces together into a vtkImageData. In this case, these 4 pieces can be collected together using a vtkMultiPieceDataSet. Note that vtkMultiPieceDataSet is intended to be included in other composite datasets eg. vtkMultiBlockDataSet, vtkHierarchicalBoxDataSet. Hence the lack of algorithms producing vtkMultiPieceDataSet.
Implementations
Sourceimpl vtkMultiPieceDataSet
impl vtkMultiPieceDataSet
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMultiPieceDataSet wrapped inside vtkNew