vtkNonMergingPointLocator

Struct vtkNonMergingPointLocator 

pub struct vtkNonMergingPointLocator(/* private fields */);
direct / check-free point insertion.

As a special sub-class of vtkPointLocator, vtkNonMergingPointLocator is intended for direct / check-free insertion of points into a vtkPoints object. In other words, any given point is always directly inserted. The name emphasizes the difference between this class and its sibling class vtkMergePoints in that the latter class performs check-based zero tolerance point insertion (or to ‘merge’ exactly duplicate / coincident points) by exploiting the uniform bin mechanism employed by the parent class vtkPointLocator. vtkPointLocator allows for generic (zero and non- zero) tolerance point insertion as well as point location.

@sa vtkIncrementalPointLocator vtkPointLocator vtkMergePoints

Implementations

Source

impl vtkNonMergingPointLocator

pub fn new() -> Self

Creates a new vtkNonMergingPointLocator wrapped inside vtkNew