pub struct vtkOctreePointLocator(/* private fields */);Expand description
an octree spatial decomposition of a set of points
Given a vtkDataSet, create an octree that is locally refined such that all leaf octants contain less than a certain amount of points. Note that there is no size constraint that a leaf octant in relation to any of its neighbors.
This class can also generate a PolyData representation of the boundaries of the spatial regions in the decomposition.
@sa vtkLocator vtkPointLocator vtkOctreePointLocatorNode
Implementations
Sourceimpl vtkOctreePointLocator
impl vtkOctreePointLocator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkOctreePointLocator wrapped inside vtkNew