pub struct vtkOverlappingAMR(/* private fields */);Expand description
hierarchical dataset of vtkUniformGrids
vtkOverlappingAMR extends vtkUniformGridAMR by exposing access to the amr meta data, which stores all structural information represented by an vtkAMRInformation object
@sa vtkAMRInformation
Implementations
Sourceimpl vtkOverlappingAMR
impl vtkOverlappingAMR
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkOverlappingAMR wrapped inside vtkNew