vtkPartitionedDataSet

Struct vtkPartitionedDataSet 

pub struct vtkPartitionedDataSet(/* private fields */);
composite dataset to encapsulates a dataset consisting of

partitions.

A vtkPartitionedDataSet dataset groups multiple datasets together. For example, say a simulation running in parallel on 16 processes generated 16 datasets that when considering together form a whole dataset. These are referred to as the partitions of the whole dataset. Now imagine that we want to load a volume of 16 partitions in a visualization cluster of 4 nodes. Each node could get 4 partitions, not necessarily forming a whole rectangular region. In this case, it is not possible to append the 4 partitions together into a vtkImageData. We can then collect these 4 partitions together using a vtkPartitionedDataSet.

It is required that all non-empty partitions have the same arrays and that they can be processed together as a whole by the same kind of filter. However, it is not required that they are of the same type. For example, it is possible to have structured datasets together with unstructured datasets as long as they are compatible meshes (i.e. can be processed together for the same kind of filter).

Implementations

Source

impl vtkPartitionedDataSet

pub fn new() -> Self

Creates a new vtkPartitionedDataSet wrapped inside vtkNew