vtkPartitionedDataSetCollection

Struct vtkPartitionedDataSetCollection 

pub struct vtkPartitionedDataSetCollection(/* private fields */);
Composite dataset that groups datasets as a collection.

vtkPartitionedDataSetCollection is a vtkCompositeDataSet that stores a collection of non-null vtkPartitionedDataSets. These items can represent different concepts depending on the context. For example, they can represent region of different materials in a simulation or parts in an assembly. It is not requires that items have anything in common. For example, they can have completely different point or cell arrays.

Implementations

Source

impl vtkPartitionedDataSetCollection

pub fn new() -> Self

Creates a new vtkPartitionedDataSetCollection wrapped inside vtkNew