vtkPentagonalPrism

Struct vtkPentagonalPrism 

pub struct vtkPentagonalPrism(/* private fields */);
a 3D cell that represents a convex prism with

pentagonal base

vtkPentagonalPrism is a concrete implementation of vtkCell to represent a linear convex 3D prism with pentagonal base. Such prism is defined by the ten points (0-9), where (0,1,2,3,4) is the base of the prism which, using the right hand rule, forms a pentagon whose normal points is in the direction of the opposite face (5,6,7,8,9).

@par Thanks: Thanks to Philippe Guerville who developed this class. Thanks to Charles Pignerol (CEA-DAM, France) who ported this class under VTK 4.
Thanks to Jean Favre (CSCS, Switzerland) who contributed to integrate this class in VTK.
Please address all comments to Jean Favre (jfavre at cscs.ch).

@par Thanks: The Interpolation functions and derivatives were changed in June 2015 by Bill Lorensen. These changes follow the formulation in: http://dilbert.engr.ucdavis.edu/~suku/nem/papers/polyelas.pdf NOTE: An additional copy of this paper is located at: http://www.vtk.org/Wiki/File:ApplicationOfPolygonalFiniteElementsInLinearElasticity.pdf

Implementations

Source

impl vtkPentagonalPrism

pub fn new() -> Self

Creates a new vtkPentagonalPrism wrapped inside vtkNew