pub struct vtkPerlinNoise(/* private fields */);Expand description
an implicit function that implements Perlin noise
vtkPerlinNoise computes a Perlin noise field as an implicit function. vtkPerlinNoise is a concrete implementation of vtkImplicitFunction. Perlin noise, originally described by Ken Perlin, is a non-periodic and continuous noise function useful for modeling real-world objects.
The amplitude and frequency of the noise pattern are adjustable. This implementation of Perlin noise is derived closely from Greg Ward’s version in Graphics Gems II.
@sa vtkImplicitFunction
Implementations
Sourceimpl vtkPerlinNoise
impl vtkPerlinNoise
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPerlinNoise wrapped inside vtkNew