pub struct vtkPixel(/* private fields */);Expand description
a cell that represents an orthogonal quadrilateral
vtkPixel is a concrete implementation of vtkCell to represent a 2D orthogonal quadrilateral. Unlike vtkQuad, the corners are at right angles, and aligned along x-y-z coordinate axes leading to large increases in computational efficiency.
Implementations