pub struct vtkPlane(/* private fields */);Expand description
perform various plane computations
vtkPlane provides methods for various plane computations. These include projecting points onto a plane, evaluating the plane equation, and returning plane normal. vtkPlane is a concrete implementation of the abstract class vtkImplicitFunction.
Implementations