vtkPlanes

Struct vtkPlanes 

pub struct vtkPlanes(/* private fields */);
implicit function for convex set of planes

vtkPlanes computes the implicit function and function gradient for a set of planes. The planes must define a convex space.

The function value is the intersection (i.e., maximum value) obtained by evaluating the each of the supplied planes. Hence the value is the maximum distance of a point to the convex region defined by the planes. The function gradient is the plane normal at the function value. Note that the normals must point outside of the convex region. Thus, a negative function value means that a point is inside the convex region.

There are several methods to define the set of planes. The most general is to supply an instance of vtkPoints and an instance of vtkDataArray. (The points define a point on the plane, and the normals corresponding plane normals.) Two other specialized ways are to 1) supply six planes defining the view frustrum of a camera, and 2) provide a bounding box.

@sa vtkImplicitBoolean vtkSpheres vtkFrustrumSource vtkCamera

Implementations

Source

impl vtkPlanes

pub fn new() -> Self

Creates a new vtkPlanes wrapped inside vtkNew