pub struct vtkPointLocator(/* private fields */);Expand description
quickly locate points in 3-space
vtkPointLocator is a spatial search object to quickly locate points in 3D. vtkPointLocator works by dividing a specified region of space into a regular array of “rectangular” buckets, and then keeping a list of points that lie in each bucket. Typical operation involves giving a position in 3D and finding the closest point.
vtkPointLocator has two distinct methods of interaction. In the first method, you supply it with a dataset, and it operates on the points in the dataset. In the second method, you supply it with an array of points, and the object operates on the array.
@warning Many other types of spatial locators have been developed such as octrees and kd-trees. These are often more efficient for the operations described here.
@warning Frequently vtkStaticPointLocator is used in lieu of vtkPointLocator. They are very similar in terms of algorithmic approach, however vtkStaticCellLocator is threaded and is typically much faster for a large number of points (on the order of 3-5x faster). For small numbers of points, vtkPointLocator is just as fast as vtkStaticPointLocator.
@sa vtkCellPicker vtkPointPicker vtkStaticPointLocator
Implementations
Sourceimpl vtkPointLocator
impl vtkPointLocator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPointLocator wrapped inside vtkNew