pub struct vtkPointsProjectedHull(/* private fields */);Expand description
the convex hull of the orthogonal
projection of the vtkPoints in the 3 coordinate directions
a subclass of vtkPoints, it maintains the counter clockwise convex hull of the points (projected orthogonally in the three coordinate directions) and has a method to test for intersection of that hull with an axis aligned rectangle. This is used for intersection tests of 3D volumes.
Implementations
Sourceimpl vtkPointsProjectedHull
impl vtkPointsProjectedHull
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPointsProjectedHull wrapped inside vtkNew