pub struct vtkPolyPlane(/* private fields */);Expand description
Implicit function that is generated by extrusion of a polyline along the Z axis
vtkPolyPlane is, as the name suggests, an extrusion of a vtkPolyLine. The extrusion direction is assumed to be the Z vector. It can be used in combination with a vtkCutter to cut a dataset with a polyplane. vtkPolyPlane is a concrete implementation of the abstract class vtkImplicitFunction.
@todo Generalize to extrusions along arbitrary directions.
Implementations
Sourceimpl vtkPolyPlane
impl vtkPolyPlane
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPolyPlane wrapped inside vtkNew