vtkPyramid

Struct vtkPyramid 

pub struct vtkPyramid(/* private fields */);
a 3D cell that represents a linear pyramid

vtkPyramid is a concrete implementation of vtkCell to represent a 3D pyramid. A pyramid consists of a rectangular base with four triangular faces. vtkPyramid uses the standard isoparametric shape functions for a linear pyramid. The pyramid is defined by the five points (0-4) where (0,1,2,3) is the base of the pyramid which, using the right hand rule, forms a quadrilaterial whose normal points in the direction of the pyramid apex at vertex #4. The parametric location of vertex #4 is [0, 0, 1].

@sa vtkConvexPointSet vtkHexahedron vtkTetra vtkVoxel vtkWedge

Implementations

Source

impl vtkPyramid

pub fn new() -> Self

Creates a new vtkPyramid wrapped inside vtkNew