pub struct vtkQuadraticEdge(/* private fields */);Expand description
cell represents a parabolic, isoparametric edge
vtkQuadraticEdge is a concrete implementation of vtkNonLinearCell to represent a one-dimensional, 3-nodes, isoparametric parabolic line. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node. The ordering of the three points defining the cell is point ids (0,1,2) where id #2 is the midedge node.
@sa vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticWedge vtkQuadraticQuad vtkQuadraticHexahedron vtkQuadraticPyramid
Implementations
Sourceimpl vtkQuadraticEdge
impl vtkQuadraticEdge
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticEdge wrapped inside vtkNew