pub struct vtkQuadraticHexahedron(/* private fields */);Expand description
cell represents a parabolic, 20-node isoparametric hexahedron
vtkQuadraticHexahedron is a concrete implementation of vtkNonLinearCell to represent a three-dimensional, 20-node isoparametric parabolic hexahedron. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node. The ordering of the twenty points defining the cell is point ids (0-7,8-19) where point ids 0-7 are the eight corner vertices of the cube; followed by twelve midedge nodes (8-19). Note that these midedge nodes correspond lie on the edges defined by (0,1), (1,2), (2,3), (3,0), (4,5), (5,6), (6,7), (7,4), (0,4), (1,5), (2,6), (3,7).
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticQuad vtkQuadraticPyramid vtkQuadraticWedge
Implementations
Sourceimpl vtkQuadraticHexahedron
impl vtkQuadraticHexahedron
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticHexahedron wrapped inside vtkNew