pub struct vtkQuadraticPolygon(/* private fields */);Expand description
a cell that represents a parabolic n-sided polygon
vtkQuadraticPolygon is a concrete implementation of vtkNonLinearCell to represent a 2D n-sided (2n nodes) parabolic polygon. The polygon cannot have any internal holes, and cannot self-intersect. The cell includes a mid-edge node for each of the n edges of the cell. The ordering of the 2n points defining the cell are point ids (0..n-1 and n..2n-1) where ids 0..n-1 define the corner vertices of the polygon; ids n..2n-1 define the midedge nodes. Define the polygon with points ordered in the counter- clockwise direction; do not repeat the last point.
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticWedge vtkQuadraticPyramid
Implementations
Sourceimpl vtkQuadraticPolygon
impl vtkQuadraticPolygon
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticPolygon wrapped inside vtkNew