pub struct vtkQuadraticQuad(/* private fields */);Expand description
cell represents a parabolic, 8-node isoparametric quad
vtkQuadraticQuad is a concrete implementation of vtkNonLinearCell to represent a two-dimensional, 8-node isoparametric parabolic quadrilateral element. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node for each of the four edges of the cell. The ordering of the eight points defining the cell are point ids (0-3,4-7) where ids 0-3 define the four corner vertices of the quad; ids 4-7 define the midedge nodes (0,1), (1,2), (2,3), (3,0).
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticWedge vtkQuadraticPyramid
Implementations
Sourceimpl vtkQuadraticQuad
impl vtkQuadraticQuad
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticQuad wrapped inside vtkNew