vtkQuadraticTetra

Struct vtkQuadraticTetra 

pub struct vtkQuadraticTetra(/* private fields */);
cell represents a parabolic, 10-node isoparametric tetrahedron

vtkQuadraticTetra is a concrete implementation of vtkNonLinearCell to represent a three-dimensional, 10-node, isoparametric parabolic tetrahedron. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node on each of the size edges of the tetrahedron. The ordering of the ten points defining the cell is point ids (0-3,4-9) where ids 0-3 are the four tetra vertices; and point ids 4-9 are the midedge nodes between (0,1), (1,2), (2,0), (0,3), (1,3), and (2,3).

Note that this class uses an internal linear tessellation for some internal operations (e.g., clipping and contouring). This means that some artifacts may appear trying to represent a non-linear interpolation function with linear tets.

@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticWedge vtkQuadraticQuad vtkQuadraticHexahedron vtkQuadraticPyramid

Implementations

Source

impl vtkQuadraticTetra

pub fn new() -> Self

Creates a new vtkQuadraticTetra wrapped inside vtkNew