pub struct vtkQuadraticWedge(/* private fields */);Expand description
cell represents a parabolic, 15-node isoparametric wedge
vtkQuadraticWedge is a concrete implementation of vtkNonLinearCell to represent a three-dimensional, 15-node isoparametric parabolic wedge. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node. The ordering of the fifteen points defining the cell is point ids (0-5,6-14) where point ids 0-5 are the six corner vertices of the wedge, defined analogously to the six points in vtkWedge (points (0,1,2) form the base of the wedge which, using the right hand rule, forms a triangle whose normal points away from the triangular face (3,4,5)); followed by nine midedge nodes (6-14). Note that these midedge nodes correspond lie on the edges defined by (0,1), (1,2), (2,0), (3,4), (4,5), (5,3), (0,3), (1,4), (2,5).
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticQuad vtkQuadraticPyramid
Implementations
Sourceimpl vtkQuadraticWedge
impl vtkQuadraticWedge
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticWedge wrapped inside vtkNew