vtkQuadratureSchemeDefinition

Struct vtkQuadratureSchemeDefinition 

pub struct vtkQuadratureSchemeDefinition(/* private fields */);
An Elemental data type that holds a definition of a numerical quadrature scheme. The definition contains the requisite information to interpolate to the so called quadrature points of the specific scheme. namely:

1)
A matrix of shape function weights(shape functions evaluated
at parametric coordinates of the quadrature points).

2)
The number of quadrature points and cell nodes. These parameters
size the matrix, and allow for convenient evaluation by users
of the definition.

Implementations

Source

impl vtkQuadratureSchemeDefinition

pub fn new() -> Self

Creates a new vtkQuadratureSchemeDefinition wrapped inside vtkNew