vtkRectilinearGrid

Struct vtkRectilinearGrid 

pub struct vtkRectilinearGrid(/* private fields */);
a dataset that is topologically regular with variable spacing in the three coordinate

directions

vtkRectilinearGrid is a data object that is a concrete implementation of vtkDataSet. vtkRectilinearGrid represents a geometric structure that is topologically regular with variable spacing in the three coordinate directions x-y-z.

To define a vtkRectilinearGrid, you must specify the dimensions of the data and provide three arrays of values specifying the coordinates along the x-y-z axes. The coordinate arrays are specified using three vtkDataArray objects (one for x, one for y, one for z).

@warning Make sure that the dimensions of the grid match the number of coordinates in the x-y-z directions. If not, unpredictable results (including program failure) may result. Also, you must supply coordinates in all three directions, even if the dataset topology is 2D, 1D, or 0D.

Implementations

Source

impl vtkRectilinearGrid

pub fn new() -> Self

Creates a new vtkRectilinearGrid wrapped inside vtkNew