vtkReebGraphSimplificationMetric

Struct vtkReebGraphSimplificationMetric 

pub struct vtkReebGraphSimplificationMetric(/* private fields */);
abstract class for custom Reeb graph

simplification metric design.

This class makes it possible to design customized simplification metric evaluation algorithms, enabling the user to control the definition of what should be considered as noise or signal in the topological filtering process.

References: “Topological persistence and simplification”, H. Edelsbrunner, D. Letscher, and A. Zomorodian, Discrete Computational Geometry, 28:511-533, 2002.

“Extreme elevation on a 2-manifold”, P.K. Agarwal, H. Edelsbrunner, J. Harer, and Y. Wang, ACM Symposium on Computational Geometry, pp. 357-365, 2004.

“Simplifying flexible isosurfaces using local geometric measures”, H. Carr, J. Snoeyink, M van de Panne, IEEE Visualization, 497-504, 2004

“Loop surgery for volumetric meshes: Reeb graphs reduced to contour trees”, J. Tierny, A. Gyulassy, E. Simon, V. Pascucci, IEEE Trans. on Vis. and Comp. Graph. (Proc of IEEE VIS), 15:1177-1184, 2009.

See Graphics/Testing/Cxx/TestReebGraph.cxx for an example of concrete implementation.

Implementations

Source

impl vtkReebGraphSimplificationMetric

pub fn new() -> Self

Creates a new vtkReebGraphSimplificationMetric wrapped inside vtkNew