vtkSelection

Struct vtkSelection 

pub struct vtkSelection(/* private fields */);
data object that represents a “selection” in VTK.

vtkSelection defines a selection. A selection is a data-object that defines which entities from another data-object are to treated as “selected”. Filters like vtkExtractSelection or vtkExtractDataArraysOverTime can then be used to extract these selected entities from the other data-object.

vtkSelection comprises of vtkSelectionNodes and optionally, an expression specified using vtkSelection::SetExpression. If non-empty, the expression is a boolean expression that defines now the selection nodes present in the selection are to be combined together to form the selection. If no expression is specified and there are multiple selection nodes, then the default expression simply combines all the selection nodes using an or operator.

Each vtkSelectionNode is used to define the selection criteria. vtkSelectionNode API lets one select what kind of entities are being selected (vtkSelectionNode::FieldType) and how they are being selected (vtkSelectionNode::ContentType).

@sa vtkSelectionNode

Implementations

Source

impl vtkSelection

pub fn new() -> Self

Creates a new vtkSelection wrapped inside vtkNew