pub struct vtkSpheres(/* private fields */);Expand description
implicit function for a set of spheres
vtkSpheres computes the implicit function and function gradient for a set of spheres. The spheres are combined via a union operation (i.e., the minimum value from the evaluation of all spheres is taken).
The function value is the distance of a point to the closest sphere, with negative values interior to the spheres, positive outside the spheres, and distance=0 on the spheres surface. The function gradient is the sphere normal at the function value.
@sa vtkPlanes vtkImplicitBoolean
Implementations
Sourceimpl vtkSpheres
impl vtkSpheres
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkSpheres wrapped inside vtkNew