vtkStaticCellLocator

Struct vtkStaticCellLocator 

pub struct vtkStaticCellLocator(/* private fields */);
perform fast cell location operations

vtkStaticCellLocator is a type of vtkAbstractCellLocator that accelerates certain operations when performing spatial operations on cells. These operations include finding a point that contains a cell, and intersecting cells with a line.

vtkStaticCellLocator is an accelerated version of vtkCellLocator. It is threaded (via vtkSMPTools), and supports one-time static construction (i.e., incremental cell insertion is not supported).

@warning vtkStaticCellLocator utilizes the following parent class parameters:

  • Automatic (default true)
  • NumberOfCellsPerNode (default 10)
  • UseExistingSearchStructure (default false)

vtkStaticCellLocator does NOT utilize the following parameters:

  • CacheCellBounds (always cached)
  • Tolerance
  • Level
  • MaxLevel
  • RetainCellLists

@warning This class is templated. It may run slower than serial execution if the code is not optimized during compilation. Build in Release or ReleaseWithDebugInfo.

@sa vtkAbstractCellLocator vtkCellLocator vtkCellTreeLocator vtkModifiedBSPTree vtkOBBTree

Implementations

Source

impl vtkStaticCellLocator

pub fn new() -> Self

Creates a new vtkStaticCellLocator wrapped inside vtkNew