pub struct vtkStaticPointLocator(/* private fields */);Expand description
quickly locate points in 3-space
vtkStaticPointLocator is a spatial search object to quickly locate points in 3D. vtkStaticPointLocator works by dividing a specified region of space into a regular array of cuboid buckets, and then keeping a list of points that lie in each bucket. Typical operation involves giving a position in 3D and finding the closest point; or finding the N closest points.
vtkStaticPointLocator is an accelerated version of vtkPointLocator. It is threaded (via vtkSMPTools), and supports one-time static construction (i.e., incremental point insertion is not supported). If you need to incrementally insert points, use the vtkPointLocator or its kin to do so.
@warning This class is templated. It may run slower than serial execution if the code is not optimized during compilation. Build in Release or ReleaseWithDebugInfo.
@warning Make sure that you review the documentation for the superclasses vtkAbstactPointLocator and vtkLocator. In particular the Automatic data member can be used to automatically determine divisions based on the average number of points per bucket.
@warning Other types of spatial locators have been developed such as octrees and kd-trees. These are often more efficient for the operations described here.
@warning Frequently vtkStaticPointLocator is used in lieu of vtkPointLocator. They are very similar in terms of algorithmic approach, however vtkStaticCellLocator is threaded and is typically much faster for a large number of points (on the order of 3-5x faster). For small numbers of points, vtkPointLocator is just as fast as vtkStaticPointLocator.
@sa vtkPointLocator vtkCellLocator vtkLocator vtkAbstractPointLocator
Implementations
Sourceimpl vtkStaticPointLocator
impl vtkStaticPointLocator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkStaticPointLocator wrapped inside vtkNew