vtkStructuredCellArray

Struct vtkStructuredCellArray 

pub struct vtkStructuredCellArray(/* private fields */);
implicit object to represent cell connectivity

vtkStructuredCellArray stores dataset topologies as an structured connectivity table listing the point ids that make up each cell.

Internally, the connectivity is stored as a vtkImplicitArray that is constructed using the SetData function by providing the dimensions of the dataset and a flag indicating whether the data should use voxel/pixel orientation.

This class was designed as a more performant alternative to vtkStructuredData::GetCellPoints.

@sa vtkCellArray vtkAbstractCellArray

Implementations

Source

impl vtkStructuredCellArray

pub fn new() -> Self

Creates a new vtkStructuredCellArray wrapped inside vtkNew