vtkStructuredGrid

Struct vtkStructuredGrid 

pub struct vtkStructuredGrid(/* private fields */);
topologically regular array of data

vtkStructuredGrid is a data object that is a concrete implementation of vtkDataSet. vtkStructuredGrid represents a geometric structure that is a topologically regular array of points. The topology is that of a cube that has been subdivided into a regular array of smaller cubes. Each point/cell can be addressed with i-j-k indices. Examples include finite difference grids.

The order and number of points must match that specified by the dimensions of the grid. The point order increases in i fastest (from 0<=i<dims[0]), then j (0<=j<dims[1]), then k (0<=k<dims[2]) where dims[] are the dimensions of the grid in the i-j-k topological directions. The number of points is dims[0]dims[1]dims[2]. The same is true for the cells of the grid. The order and number of cells must match that specified by the dimensions of the grid. The cell order increases in i fastest (from 0<=i<(dims[0]-1)), then j (0<=j<(dims[1]-1)), then k (0<=k<(dims[2]-1)) The number of cells is (dims[0]-1)(dims[1]-1)(dims[2]-1).

vtkStructuredGrid has the ability to blank, or “turn-off” points and cells in the dataset. This is done by setting vtkDataSetAttributes::HIDDENPOINT or vtkDataSetAttributes::HIDDENCELL in the ghost array for each point / cell that needs to be blanked.

Implementations

Source

impl vtkStructuredGrid

pub fn new() -> Self

Creates a new vtkStructuredGrid wrapped inside vtkNew