vtkStructuredPoints

Struct vtkStructuredPoints 

pub struct vtkStructuredPoints(/* private fields */);
A subclass of ImageData.

StructuredPoints is a subclass of ImageData that requires the data extent to exactly match the update extent. Normal image data allows that the data extent may be larger than the update extent. StructuredPoints also defines the origin differently that vtkImageData. For structured points the origin is the location of first point. Whereas images define the origin as the location of point 0, 0, 0. Image Origin is stored in ivar, and structured points have special methods for setting/getting the origin/extents.

Implementations

Source

impl vtkStructuredPoints

pub fn new() -> Self

Creates a new vtkStructuredPoints wrapped inside vtkNew