vtkSuperquadric

Struct vtkSuperquadric 

pub struct vtkSuperquadric(/* private fields */);
implicit function for a Superquadric

vtkSuperquadric computes the implicit function and function gradient for a superquadric. vtkSuperquadric is a concrete implementation of vtkImplicitFunction. The superquadric is centered at Center and axes of rotation is along the y-axis. (Use the superclass’ vtkImplicitFunction transformation matrix if necessary to reposition.) Roundness parameters (PhiRoundness and ThetaRoundness) control the shape of the superquadric. The Toroidal boolean controls whether a toroidal superquadric is produced. If so, the Thickness parameter controls the thickness of the toroid: 0 is the thinnest allowable toroid, and 1 has a minimum sized hole. The Scale parameters allow the superquadric to be scaled in x, y, and z (normal vectors are correctly generated in any case). The Size parameter controls size of the superquadric.

This code is based on “Rigid physically based superquadrics”, A. H. Barr, in “Graphics Gems III”, David Kirk, ed., Academic Press, 1992.

@warning The Size and Thickness parameters control coefficients of superquadric generation, and may do not exactly describe the size of the superquadric.

Implementations

Source

impl vtkSuperquadric

pub fn new() -> Self

Creates a new vtkSuperquadric wrapped inside vtkNew