pub struct vtkTetra(/* private fields */);Expand description
a 3D cell that represents a tetrahedron
vtkTetra is a concrete implementation of vtkCell to represent a 3D tetrahedron. vtkTetra uses the standard isoparametric shape functions for a linear tetrahedron. The tetrahedron is defined by the four points (0-3); where (0,1,2) is the base of the tetrahedron which, using the right hand rule, forms a triangle whose normal points in the direction of the fourth point.
@sa vtkConvexPointSet vtkHexahedron vtkPyramid vtkVoxel vtkWedge
Implementations