pub struct vtkTreeBFSIterator(/* private fields */);Expand description
breadth first search iterator through a vtkTree
vtkTreeBFSIterator performs a breadth first search traversal of a tree.
After setting up the iterator, the normal mode of operation is to
set up a while(iter->HasNext()) loop, with the statement
vtkIdType vertex = iter->Next() inside the loop.
@par Thanks: Thanks to David Doria for submitting this class.
Implementations
Sourceimpl vtkTreeBFSIterator
impl vtkTreeBFSIterator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTreeBFSIterator wrapped inside vtkNew