vtkTreeDFSIterator

Struct vtkTreeDFSIterator 

pub struct vtkTreeDFSIterator(/* private fields */);
depth first iterator through a vtkGraph

vtkTreeDFSIterator performs a depth first search traversal of a tree.

First, you must set the tree on which you are going to iterate, and then optionally set the starting vertex and mode. The mode is either DISCOVER (default), in which case vertices are visited as they are first reached, or FINISH, in which case vertices are visited when they are done, i.e. all adjacent vertices have been discovered already.

After setting up the iterator, the normal mode of operation is to set up a while(iter->HasNext()) loop, with the statement vtkIdType vertex = iter->Next() inside the loop.

Implementations

Source

impl vtkTreeDFSIterator

pub fn new() -> Self

Creates a new vtkTreeDFSIterator wrapped inside vtkNew