pub struct vtkTriangleStrip(/* private fields */);Expand description
a cell that represents a triangle strip
vtkTriangleStrip is a concrete implementation of vtkCell to represent a 2D triangle strip. A triangle strip is a compact representation of triangles connected edge to edge in strip fashion. The connectivity of a triangle strip is three points defining an initial triangle, then for each additional triangle, a single point that, combined with the previous two points, defines the next triangle.
Implementations
Sourceimpl vtkTriangleStrip
impl vtkTriangleStrip
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTriangleStrip wrapped inside vtkNew