pub struct vtkUnstructuredGrid(/* private fields */);Expand description
dataset represents arbitrary combinations of
all possible cell types
vtkUnstructuredGrid is a data object that is a concrete implementation of vtkDataSet. vtkUnstructuredGrid represents any combinations of any cell types. This includes 0D (e.g., points), 1D (e.g., lines, polylines), 2D (e.g., triangles, polygons), and 3D (e.g., hexahedron, tetrahedron, polyhedron, etc.). vtkUnstructuredGrid provides random access to cells, as well as topological information (such as lists of cells using each point).
Implementations
Sourceimpl vtkUnstructuredGrid
impl vtkUnstructuredGrid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUnstructuredGrid wrapped inside vtkNew