pub struct vtkWedge(/* private fields */);Expand description
a 3D cell that represents a linear wedge
vtkWedge is a concrete implementation of vtkCell to represent a linear 3D wedge. A wedge consists of two triangular and three quadrilateral faces and is defined by the six points (0-5). vtkWedge uses the standard isoparametric shape functions for a linear wedge. The wedge is defined by the six points (0-5) where (0,1,2) is the base of the wedge which, using the right hand rule, forms a triangle whose normal points outward (away from the triangular face (3,4,5)).
@sa vtkConvexPointSet vtkHexahedron vtkPyramid vtkTetra vtkVoxel
Implementations