Module vtkCommonExecutionModel

Module vtkCommonExecutionModel 

Structs

vtkAggregateToPartitionedDataSetCollection
Aggregate results in the vtkEndFor
vtkAlgorithm
Superclass for all sources, filters, and sinks in VTK.
vtkAlgorithmOutput
Proxy object to connect input/output ports.
vtkAnnotationLayersAlgorithm
Superclass for algorithms that produce only vtkAnnotationLayers as output
vtkArrayDataAlgorithm
Superclass for algorithms that produce
vtkCachedStreamingDemandDrivenPipeline
vtkCachedStreamingDemandDrivenPipeline
vtkCastToConcrete
works around type-checking limitations
vtkCellGridAlgorithm
Superclass for algorithms that produce only polydata as output
vtkCompositeDataPipeline
Executive supporting composite datasets.
vtkCompositeDataSetAlgorithm
Superclass for algorithms that produce only vtkCompositeDataSet as output
vtkDataObjectAlgorithm
Superclass for algorithms that produce only data object as output
vtkDataSetAlgorithm
Superclass for algorithms that produce output of the same type as input
vtkDemandDrivenPipeline
Executive supporting on-demand execution.
vtkDirectedGraphAlgorithm
Superclass for algorithms that produce only directed graph as output
vtkEndFor
vtkEndFor define the end of the sub-pipeline to loop
vtkEnsembleSource
source that manages dataset ensembles
vtkExplicitStructuredGridAlgorithm
Superclass for algorithms that produce only
vtkExtentRCBPartitioner
This method partitions a global extent to N partitions where N is a user
vtkExtentSplitter
Split an extent across other extents.
vtkExtentTranslator
Generates a structured extent from unstructured.
vtkForEach
Algorithm allowing to implement a for loop using the VTK pipeline and a sister filter
vtkGraphAlgorithm
Superclass for algorithms that produce only graph as output
vtkHierarchicalBoxDataSetAlgorithm
superclass for algorithms that
vtkImageToStructuredGrid
a structured grid instance.
vtkImageToStructuredPoints
Attaches image pipeline to VTK.
vtkMoleculeAlgorithm
Superclass for algorithms that operate on
vtkMultiBlockDataSetAlgorithm
Superclass for algorithms that produce only vtkMultiBlockDataSet as output
vtkMultiTimeStepAlgorithm
Superclass for algorithms that would like to make multiple time requests
vtkNonOverlappingAMRAlgorithm
produce vtkNonOverlappingAMR as output.
vtkOverlappingAMRAlgorithm
A base class for all algorithms that take as input vtkOverlappingAMR and
vtkPassInputTypeAlgorithm
Superclass for algorithms that produce output of the same type as input
vtkPiecewiseFunctionAlgorithm
Superclass for algorithms that produce only piecewise function as output
vtkPiecewiseFunctionShiftScale
vtkPointSetAlgorithm
Superclass for algorithms that produce output of the same type as input
vtkPolyDataAlgorithm
Superclass for algorithms that produce only polydata as output
vtkProgressObserver
Basic class to optionally replace vtkAlgorithm progress functionality.
vtkRectilinearGridAlgorithm
Superclass for algorithms that produce only rectilinear grid as output
vtkSMPProgressObserver
Progress observer that is thread safe
vtkSelectionAlgorithm
Superclass for algorithms that produce only Selection as output
vtkSimpleScalarTree
organize data according to scalar values (used to accelerate contouring operations)
vtkSpanSpace
organize data according to scalar span space
vtkSphereTree
class to build and traverse sphere trees
vtkStreamingDemandDrivenPipeline
Executive supporting partial updates.
vtkStructuredGridAlgorithm
Superclass for algorithms that produce only structured grid as output
vtkTableAlgorithm
Superclass for algorithms that produce only vtkTables as output
vtkThreadedCompositeDataPipeline
Executive that works in parallel
vtkTimeRange
vtkExecutionRange using time to dispatch in a vtkForEach sub-pipeline
vtkTreeAlgorithm
Superclass for algorithms that produce only Tree as output
vtkTrivialConsumer
Consumer to consume data off of a pipeline.
vtkTrivialProducer
Producer for stand-alone data objects.
vtkUndirectedGraphAlgorithm
Superclass for algorithms that produce undirected graph as output
vtkUniformGridAMRAlgorithm
vtkUniformGridAMR as output.
vtkUniformGridPartitioner
A concrete implementation of vtkMultiBlockDataSetAlgorithm that provides functionality for partitioning a uniform grid. The partitioning method that is used is Recursive Coordinate Bisection (RCB) where each time the longest dimension is split.
vtkUnstructuredGridAlgorithm
Superclass for algorithms that produce only unstructured grid as output
vtkUnstructuredGridBaseAlgorithm
Superclass for algorithms that