vtkAlgorithm

Struct vtkAlgorithm 

pub struct vtkAlgorithm(/* private fields */);
Superclass for all sources, filters, and sinks in VTK.

vtkAlgorithm is the superclass for all sources, filters, and sinks in VTK. It defines a generalized interface for executing data processing algorithms. Pipeline connections are associated with input and output ports that are independent of the type of data passing through the connections.

Instances may be used independently or within pipelines with a variety of architectures and update mechanisms. Pipelines are controlled by instances of vtkExecutive. Every vtkAlgorithm instance has an associated vtkExecutive when it is used in a pipeline. The executive is responsible for data flow.

Implementations

Source

impl vtkAlgorithm

pub fn new() -> Self

Creates a new vtkAlgorithm wrapped inside vtkNew