pub struct vtkAlgorithmOutput(/* private fields */);Expand description
Proxy object to connect input/output ports.
vtkAlgorithmOutput is a proxy object returned by the GetOutputPort method of vtkAlgorithm. It may be passed to the SetInputConnection, AddInputConnection, or RemoveInputConnection methods of another vtkAlgorithm to establish a connection between an output and input port. The connection is not stored in the proxy object: it is simply a convenience for creating or removing connections.
Implementations
Sourceimpl vtkAlgorithmOutput
impl vtkAlgorithmOutput
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkAlgorithmOutput wrapped inside vtkNew