pub struct vtkCompositeDataSetAlgorithm(/* private fields */);Expand description
Superclass for algorithms that produce only vtkCompositeDataSet as output
Algorithms that take any type of data object (including composite dataset) and produce a vtkCompositeDataSet in the output can subclass from this class.
Implementations
Sourceimpl vtkCompositeDataSetAlgorithm
impl vtkCompositeDataSetAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCompositeDataSetAlgorithm wrapped inside vtkNew