pub struct vtkEnsembleSource(/* private fields */);Expand description
source that manages dataset ensembles
vtkEnsembleSource manages a collection of data sources in order to represent a dataset ensemble. It has the ability to provide meta-data about the ensemble in the form of a table, using the META_DATA key as well as accept a pipeline request using the UPDATE_MEMBER key. Note that it is expected that all ensemble members produce data of the same type.
Implementations
Sourceimpl vtkEnsembleSource
impl vtkEnsembleSource
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkEnsembleSource wrapped inside vtkNew