pub struct vtkExtentTranslator(/* private fields */);Expand description
Generates a structured extent from unstructured.
vtkExtentTranslator generates a structured extent from an unstructured extent. It uses a recursive scheme that splits the largest axis. A hard coded extent can be used for a starting point.
Implementations
Sourceimpl vtkExtentTranslator
impl vtkExtentTranslator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkExtentTranslator wrapped inside vtkNew