pub struct vtkHierarchicalBoxDataSetAlgorithm(/* private fields */);Expand description
superclass for algorithms that
produce vtkHierarchicalBoxDataSet as output.
Algorithms that take any type of data object (including composite dataset) and produce a vtkHierarchicalBoxDataSet in the output can subclass from this class.
Implementations
Sourceimpl vtkHierarchicalBoxDataSetAlgorithm
impl vtkHierarchicalBoxDataSetAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkHierarchicalBoxDataSetAlgorithm wrapped inside vtkNew