vtkImageToStructuredPoints

Struct vtkImageToStructuredPoints 

pub struct vtkImageToStructuredPoints(/* private fields */);
Attaches image pipeline to VTK.

vtkImageToStructuredPoints changes an image cache format to a structured points dataset. It takes an Input plus an optional VectorInput. The VectorInput converts the RGB scalar components of the VectorInput to vector pointdata attributes. This filter will try to reference count the data but in some cases it must make a copy.

Implementations

Source

impl vtkImageToStructuredPoints

pub fn new() -> Self

Creates a new vtkImageToStructuredPoints wrapped inside vtkNew