pub struct vtkMultiBlockDataSetAlgorithm(/* private fields */);Expand description
Superclass for algorithms that produce only vtkMultiBlockDataSet as output
Algorithms that take any type of data object (including composite dataset) and produce a vtkMultiBlockDataSet in the output can subclass from this class.
Implementations
Sourceimpl vtkMultiBlockDataSetAlgorithm
impl vtkMultiBlockDataSetAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMultiBlockDataSetAlgorithm wrapped inside vtkNew