vtkProgressObserver

Struct vtkProgressObserver 

pub struct vtkProgressObserver(/* private fields */);
Basic class to optionally replace vtkAlgorithm progress functionality.

When the basic functionality in vtkAlgorithm that reports progress is not enough, a subclass of vtkProgressObserver can be used to provide custom functionality. The main use case for this is when an algorithm’s RequestData() is called from multiple threads in parallel - the basic functionality in vtkAlgorithm is not thread safe. vtkSMPProgressObserver can handle this situation by routing progress from each thread to a thread local vtkProgressObserver, which will invoke events separately for each thread.

Implementations

Source

impl vtkProgressObserver

pub fn new() -> Self

Creates a new vtkProgressObserver wrapped inside vtkNew