vtkSMPProgressObserver

Struct vtkSMPProgressObserver 

pub struct vtkSMPProgressObserver(/* private fields */);
Progress observer that is thread safe

vtkSMPProgressObserver is designed to handle progress events coming from an algorithm in a thread safe way. It does this by using thread local objects that it updates. To receive the progress information, one has to listen to the local observer in the same thread. Since the execution will be somewhat load balanced, it may be enough to do this only on the main thread.

Implementations

Source

impl vtkSMPProgressObserver

pub fn new() -> Self

Creates a new vtkSMPProgressObserver wrapped inside vtkNew