vtkSelectionAlgorithm

Struct vtkSelectionAlgorithm 

pub struct vtkSelectionAlgorithm(/* private fields */);
Superclass for algorithms that produce only Selection as output

vtkSelectionAlgorithm is a convenience class to make writing algorithms easier. It is also designed to help transition old algorithms to the new pipeline edgehitecture. There are some assumptions and defaults made by this class you should be aware of. This class defaults such that your filter will have one input port and one output port. If that is not the case simply change it with SetNumberOfInputPorts etc. See this class constructor for the default. This class also provides a FillInputPortInfo method that by default says that all inputs will be Selection. If that isn’t the case then please override this method in your subclass. You should implement the subclass’s algorithm into RequestData( request, inputVec, outputVec).

@par Thanks: Thanks to Patricia Crossno, Ken Moreland, Andrew Wilson and Brian Wylie from Sandia National Laboratories for their help in developing this class.

Implementations

Source

impl vtkSelectionAlgorithm

pub fn new() -> Self

Creates a new vtkSelectionAlgorithm wrapped inside vtkNew