pub struct vtkStreamingDemandDrivenPipeline(/* private fields */);Expand description
Executive supporting partial updates.
vtkStreamingDemandDrivenPipeline is an executive that supports updating only a portion of the data set in the pipeline. This is the style of pipeline update that is provided by the old-style VTK 4.x pipeline. Instead of always updating an entire data set, this executive supports asking for pieces or sub-extents.
Implementations
Sourceimpl vtkStreamingDemandDrivenPipeline
impl vtkStreamingDemandDrivenPipeline
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkStreamingDemandDrivenPipeline wrapped inside vtkNew