vtkThreadedCompositeDataPipeline

Struct vtkThreadedCompositeDataPipeline 

pub struct vtkThreadedCompositeDataPipeline(/* private fields */);
Executive that works in parallel

vtkThreadedCompositeDataPipeline processes a composite data object in parallel using the SMP framework. It does this by creating a vector of data objects (the pieces of the composite data) and processing them using vtkSMPTools::For. Note that this requires that the algorithm implement all pipeline passes in a re-entrant way. It should store/retrieve all state changes using input and output information objects, which are unique to each thread.

Implementations

Source

impl vtkThreadedCompositeDataPipeline

pub fn new() -> Self

Creates a new vtkThreadedCompositeDataPipeline wrapped inside vtkNew