pub struct vtkTrivialConsumer(/* private fields */);Expand description
Consumer to consume data off of a pipeline.
vtkTrivialConsumer caps off a pipeline so that no output data is left hanging around when a pipeline executes when data is set to be released (see vtkDataObject::SetGlobalReleaseDataFlag). This is intended to be used for tools such as Catalyst and not end users.
Implementations
Sourceimpl vtkTrivialConsumer
impl vtkTrivialConsumer
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTrivialConsumer wrapped inside vtkNew