pub struct vtkTrivialProducer(/* private fields */);Expand description
Producer for stand-alone data objects.
vtkTrivialProducer allows stand-alone data objects to be connected as inputs in a pipeline. All data objects that are connected to a pipeline involving vtkAlgorithm must have a producer. This trivial producer allows data objects that are hand-constructed in a program without another vtk producer to be connected.
Implementations
Sourceimpl vtkTrivialProducer
impl vtkTrivialProducer
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTrivialProducer wrapped inside vtkNew