vtkUniformGridAMRAlgorithm

Struct vtkUniformGridAMRAlgorithm 

pub struct vtkUniformGridAMRAlgorithm(/* private fields */);
vtkUniformGridAMR as output.

A base class for all algorithms that take as input any type of data object including composite datasets and produce vtkUniformGridAMR in the output.

Implementations

Source

impl vtkUniformGridAMRAlgorithm

pub fn new() -> Self

Creates a new vtkUniformGridAMRAlgorithm wrapped inside vtkNew