pub struct vtkUniformGridPartitioner(/* private fields */);Expand description
A concrete implementation of vtkMultiBlockDataSetAlgorithm that provides functionality for partitioning a uniform grid. The partitioning method that is used is Recursive Coordinate Bisection (RCB) where each time the longest dimension is split.
@sa vtkStructuredGridPartitioner vtkRectilinearGridPartitioner
Implementations
Sourceimpl vtkUniformGridPartitioner
impl vtkUniformGridPartitioner
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUniformGridPartitioner wrapped inside vtkNew