pub struct vtkUnstructuredGridBaseAlgorithm(/* private fields */);Expand description
Superclass for algorithms that
produce only vtkUnstructureGridBase subclasses as output
vtkUnstructuredGridBaseAlgorithm is a convenience class to make writing algorithms easier. There are some assumptions and defaults made by this class you should be aware of. This class defaults such that your filter will have one input port and one output port. If that is not the case simply change it with SetNumberOfInputPorts etc. See this classes constructor for the default. This class also provides a FillInputPortInfo method that by default says that all inputs will be UnstructuredGridBase. If that isn’t the case then please override this method in your subclass.
Implementations
Sourceimpl vtkUnstructuredGridBaseAlgorithm
impl vtkUnstructuredGridBaseAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUnstructuredGridBaseAlgorithm wrapped inside vtkNew