vtkFFT

Struct vtkFFT 

pub struct vtkFFT(/* private fields */);
perform Discrete Fourier Transforms

vtkFFT provides methods to perform Discrete Fourier Transforms (DFT). These include providing forward and reverse Fourier transforms. The current implementation uses the third-party library kissfft.

The terminology tries to follow the Numpy terminology, that is :

  • Fft means the Fast Fourier Transform algorithm
  • Prefix R stands for Real (meaning optimized function for real inputs)
  • Prefix I stands for Inverse

Some functions provides pointer-based version of themself in order to prevent copying memory when possible.

Implementations

Source

impl vtkFFT

pub fn new() -> Self

Creates a new vtkFFT wrapped inside vtkNew