pub struct vtkMatrix4x4(/* private fields */);Expand description
represent and manipulate 4x4 transformation matrices
vtkMatrix4x4 is a class to represent and manipulate 4x4 matrices. Specifically, it is designed to work on 4x4 transformation matrices found in 3D rendering using homogeneous coordinates [x y z w]. Many of the methods take an array of 16 doubles in row-major format. Note that OpenGL stores matrices in column-major format, so the matrix contents must be transposed when they are moved between OpenGL and VTK. @sa vtkTransform
Implementations
Sourceimpl vtkMatrix4x4
impl vtkMatrix4x4
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMatrix4x4 wrapped inside vtkNew