vtkPolynomialSolversUnivariate

Struct vtkPolynomialSolversUnivariate 

pub struct vtkPolynomialSolversUnivariate(/* private fields */);
polynomial solvers

vtkPolynomialSolversUnivariate provides solvers for univariate polynomial equations with real coefficients. The Tartaglia-Cardan and Ferrari solvers work on polynomials of fixed degree 3 and 4, respectively. The Lin-Bairstow and Sturm solvers work on polynomials of arbitrary degree. The Sturm solver is the most robust solver but only reports roots within an interval and does not report multiplicities. The Lin-Bairstow solver reports multiplicities.

For difficult polynomials, you may wish to use FilterRoots to eliminate some of the roots reported by the Sturm solver. FilterRoots evaluates the derivatives near each root to eliminate cases where a local minimum or maximum is close to zero.

@par Thanks: Thanks to Philippe Pebay, Korben Rusek, David Thompson, and Maurice Rojas for implementing these solvers.

Implementations

Source

impl vtkPolynomialSolversUnivariate

pub fn new() -> Self

Creates a new vtkPolynomialSolversUnivariate wrapped inside vtkNew