pub struct vtkRungeKutta45(/* private fields */);Expand description
Integrate an initial value problem using 5th
order Runge-Kutta method with adaptive stepsize control.
This is a concrete sub-class of vtkInitialValueProblemSolver. It uses a 5th order Runge-Kutta method with stepsize control to obtain the values of a set of functions at the next time step. The stepsize is adjusted by calculating an estimated error using an embedded 4th order Runge-Kutta formula: Press, W. H. et al., 1992, Numerical Recipes in Fortran, Second Edition, Cambridge University Press Cash, J.R. and Karp, A.H. 1990, ACM Transactions on Mathematical Software, vol 16, pp 201-222
@sa vtkInitialValueProblemSolver vtkRungeKutta4 vtkRungeKutta2 vtkFunctionSet
Implementations
Sourceimpl vtkRungeKutta45
impl vtkRungeKutta45
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkRungeKutta45 wrapped inside vtkNew