pub struct vtkContourValues(/* private fields */);Expand description
helper object to manage setting and generating contour values
vtkContourValues is a general class to manage the creation, generation, and retrieval of contour values. This class serves as a helper class for contouring classes, or those classes operating on lists of contour values.
@sa vtkContourFilter
Implementations
Sourceimpl vtkContourValues
impl vtkContourValues
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkContourValues wrapped inside vtkNew