vtkHeap

Struct vtkHeap 

pub struct vtkHeap(/* private fields */);
replacement for malloc/free and new/delete

This class is a replacement for malloc/free and new/delete for software that has inherent memory leak or performance problems. For example, external software such as the PLY library (vtkPLY) and VRML importer (vtkVRMLImporter) are often written with lots of malloc() calls but without the corresponding free() invocations. The class vtkOrderedTriangulator may create and delete millions of new/delete calls. This class allows the overloading of the C++ new operator (or other memory allocation requests) by using the method AllocateMemory(). Memory is deleted with an invocation of CleanAll() (which deletes ALL memory; any given memory allocation cannot be deleted). Note: a block size can be used to control the size of each memory allocation. Requests for memory are fulfilled from the block until the block runs out, then a new block is created.

@warning Do not use this class as a general replacement for system memory allocation. This class should be used only as a last resort if memory leaks cannot be tracked down and eliminated by conventional means. Also, deleting memory from vtkHeap is not supported. Only the deletion of the entire heap is. (A Reset() method allows you to reuse previously allocated memory.)

@sa vtkVRMLImporter vtkPLY vtkOrderedTriangulator

Implementations

Source

impl vtkHeap

pub fn new() -> Self

Creates a new vtkHeap wrapped inside vtkNew