pub struct vtkDirectory(/* private fields */);Expand description
OS independent class for access and manipulation of system directories
vtkDirectory provides a portable way of finding the names of the files in a system directory. It also provides methods of manipulating directories.
@warning vtkDirectory works with windows and unix only.
Implementations
Sourceimpl vtkDirectory
impl vtkDirectory
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkDirectory wrapped inside vtkNew