vtkSocketCollection

Struct vtkSocketCollection 

pub struct vtkSocketCollection(/* private fields */);
a collection for sockets.

Apart from being vtkCollection subclass for sockets, this class provides means to wait for activity on all the sockets in the collection simultaneously.

Implementations

Source

impl vtkSocketCollection

pub fn new() -> Self

Creates a new vtkSocketCollection wrapped inside vtkNew