pub struct vtkTimerLog(/* private fields */);Expand description
Timer support and logging
vtkTimerLog contains walltime and cputime measurements associated with a given event. These results can be later analyzed when “dumping out” the table.
In addition, vtkTimerLog allows the user to simply get the current time, and to start/stop a simple timer separate from the timing table logging.
Implementations
Sourceimpl vtkTimerLog
impl vtkTimerLog
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTimerLog wrapped inside vtkNew