pub struct vtkIdentityTransform(/* private fields */);Expand description
a transform that doesn’t do anything
vtkIdentityTransform is a transformation which will simply pass coordinate data unchanged. All other transform types can also do this, however, the vtkIdentityTransform does so with much greater efficiency. @sa vtkLinearTransform
Implementations
Sourceimpl vtkIdentityTransform
impl vtkIdentityTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkIdentityTransform wrapped inside vtkNew