pub struct vtkLandmarkTransform(/* private fields */);Expand description
a linear transform specified by two corresponding point sets
A vtkLandmarkTransform is defined by two sets of landmarks, the transform computed gives the best fit mapping one onto the other, in a least squares sense. The indices are taken to correspond, so point 1 in the first set will get mapped close to point 1 in the second set, etc. Call SetSourceLandmarks and SetTargetLandmarks to specify the two sets of landmarks, ensure they have the same number of points. @warning Whenever you add, subtract, or set points you must call Modified() on the vtkPoints object, or the transformation might not update. @sa vtkLinearTransform
Implementations
Sourceimpl vtkLandmarkTransform
impl vtkLandmarkTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkLandmarkTransform wrapped inside vtkNew