pub struct vtkMatrixToLinearTransform(/* private fields */);Expand description
convert a matrix to a transform
This is a very simple class which allows a vtkMatrix4x4 to be used in place of a vtkLinearTransform or vtkAbstractTransform. For example, if you use it as a proxy between a matrix and vtkTransformPolyDataFilter then any modifications to the matrix will automatically be reflected in the output of the filter. @sa vtkTransform vtkMatrix4x4 vtkMatrixToHomogeneousTransform
Implementations
Sourceimpl vtkMatrixToLinearTransform
impl vtkMatrixToLinearTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMatrixToLinearTransform wrapped inside vtkNew