vtkPerspectiveTransform

Struct vtkPerspectiveTransform 

pub struct vtkPerspectiveTransform(/* private fields */);
describes a 4x4 matrix transformation

A vtkPerspectiveTransform can be used to describe the full range of homogeneous transformations. It was designed in particular to describe a camera-view of a scene.

The order in which you set up the display coordinates (via AdjustZBuffer() and AdjustViewport()), the projection (via Perspective(), Frustum(), or Ortho()) and the camera view (via SetupCamera()) are important. If the transform is in PreMultiply mode, which is the default, set the Viewport and ZBuffer first, then the projection, and finally the camera view. Once the view is set up, the Translate and Rotate methods can be used to move the camera around in world coordinates. If the Oblique() or Stereo() methods are used, they should be called just before SetupCamera().

In PostMultiply mode, you must perform all transformations in the opposite order. This is necessary, for example, if you already have a perspective transformation set up but must adjust the viewport. Another example is if you have a view transformation, and wish to perform translations and rotations in the camera's coordinate system rather than in world coordinates.

The SetInput and Concatenate methods can be used to create a transformation pipeline with vtkPerspectiveTransform. See vtkTransform for more information on the transformation pipeline. @sa vtkGeneralTransform vtkTransform vtkMatrix4x4 vtkCamera

Implementations

Source

impl vtkPerspectiveTransform

pub fn new() -> Self

Creates a new vtkPerspectiveTransform wrapped inside vtkNew