vtkSphericalTransform

Struct vtkSphericalTransform 

pub struct vtkSphericalTransform(/* private fields */);
spherical to rectangular coords and back

vtkSphericalTransform will convert (r,phi,theta) coordinates to (x,y,z) coordinates and back again. The angles are given in radians. By default, it converts spherical coordinates to rectangular, but GetInverse() returns a transform that will do the opposite. The equation that is used is x = r*sin(phi)cos(theta), y = rsin(phi)sin(theta), z = rcos(phi). @warning This transform is not well behaved along the line x=y=0 (i.e. along the z-axis) @sa vtkCylindricalTransform vtkGeneralTransform

Implementations

Source

impl vtkSphericalTransform

pub fn new() -> Self

Creates a new vtkSphericalTransform wrapped inside vtkNew