pub struct vtkTransform2D(/* private fields */);Expand description
describes linear transformations via a 3x3 matrix
A vtkTransform2D can be used to describe the full range of linear (also known as affine) coordinate transformations in two dimensions, which are internally represented as a 3x3 homogeneous transformation matrix. When you create a new vtkTransform2D, it is always initialized to the identity transformation.
All multiplicitive operations (Translate, Rotate, Scale, etc) are post-multiplied in this class (i.e. add them in the reverse of the order that they should be applied).
This class performs all of its operations in a right handed coordinate system with right handed rotations. Some other graphics libraries use left handed coordinate systems and rotations.
Implementations
Sourceimpl vtkTransform2D
impl vtkTransform2D
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTransform2D wrapped inside vtkNew