pub struct vtkParametricBoy(/* private fields */);Expand description
Generate Boy’s surface.
vtkParametricBoy generates Boy’s surface. This is a Model of the projective plane without singularities. It was found by Werner Boy on assignment from David Hilbert.
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricBoy
impl vtkParametricBoy
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricBoy wrapped inside vtkNew