pub struct vtkParametricRandomHills(/* private fields */);Expand description
Generate a surface covered with randomly placed hills.
vtkParametricRandomHills generates a surface covered with randomly placed hills. Hills will vary in shape and height since the presence of nearby hills will contribute to the shape and height of a given hill. An option is provided for placing hills on a regular grid on the surface. In this case the hills will all have the same shape and height.
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricRandomHills
impl vtkParametricRandomHills
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricRandomHills wrapped inside vtkNew