pub struct vtkParametricSuperToroid(/* private fields */);Expand description
Generate a supertoroid.
vtkParametricSuperToroid generates a supertoroid. Essentially a supertoroid is a torus with the sine and cosine terms raised to a power. A supertoroid is a versatile primitive that is controlled by four parameters r0, r1, n1 and n2. r0, r1 determine the type of torus whilst the value of n1 determines the shape of the torus ring and n2 determines the shape of the cross section of the ring. It is the different values of these powers which give rise to a family of 3D shapes that are all basically toroidal in shape.
For further information about this surface, please consult the technical description “Parametric surfaces” in http://www.vtk.org/publications in the “VTK Technical Documents” section in the VTk.org web pages.
Also see: http://paulbourke.net/geometry/torus/#super.
@warning Care needs to be taken specifying the bounds correctly. You may need to carefully adjust MinimumU, MinimumV, MaximumU, MaximumV.
@par Thanks: Andrew Maclean andrew.amaclean@gmail.com for creating and contributing the class.
Implementations
Sourceimpl vtkParametricSuperToroid
impl vtkParametricSuperToroid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkParametricSuperToroid wrapped inside vtkNew