pub struct vtkArchiver(/* private fields */);Expand description
Writes an archive
vtkArchiver is a base class for constructing an archive. The default implementation constructs a directory at the location of the ArchiveName and populates it with files and directories as requested by Insert(). Classes that derive from vtkArchiver can customize the output using such features as compression, in-memory serialization and third-party archival tools.
Implementations
Sourceimpl vtkArchiver
impl vtkArchiver
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkArchiver wrapped inside vtkNew