pub struct vtkByteSwap(/* private fields */);Expand description
perform machine dependent byte swapping
vtkByteSwap is used by other classes to perform machine dependent byte swapping. Byte swapping is often used when reading or writing binary files.
Implementations
Sourceimpl vtkByteSwap
impl vtkByteSwap
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkByteSwap wrapped inside vtkNew