pub struct vtkCollectionIterator(/* private fields */);Expand description
iterator through a vtkCollection.
vtkCollectionIterator provides an alternative way to traverse through the objects in a vtkCollection. Unlike the collection’s built in interface, this allows multiple iterators to simultaneously traverse the collection. If items are removed from the collection, only the iterators currently pointing to those items are invalidated. Other iterators will still continue to function normally.
Implementations
Sourceimpl vtkCollectionIterator
impl vtkCollectionIterator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCollectionIterator wrapped inside vtkNew