vtkFloatArray

Struct vtkFloatArray 

pub struct vtkFloatArray(/* private fields */);
dynamic, self-adjusting array of float

vtkFloatArray is an array of values of type float. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.

Implementations

Source

impl vtkFloatArray

pub fn new() -> Self

Creates a new vtkFloatArray wrapped inside vtkNew