vtkIdList

Struct vtkIdList 

pub struct vtkIdList(/* private fields */);
list of point or cell ids

vtkIdList is used to represent and pass data id’s between objects. vtkIdList may represent any type of integer id, but usually represents point and cell ids.

Implementations

Source

impl vtkIdList

pub fn new() -> Self

Creates a new vtkIdList wrapped inside vtkNew