pub struct vtkLongLongArray(/* private fields */);Expand description
dynamic, self-adjusting array of long long
vtkLongLongArray is an array of values of type long long. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
This class should not be used directly, as it only exists on systems where the long long type is defined. If you need a 64 bit integer data array, use vtkTypeInt64Array instead.
Implementations
Sourceimpl vtkLongLongArray
impl vtkLongLongArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkLongLongArray wrapped inside vtkNew