pub struct vtkLookupTable(/* private fields */);Expand description
map scalar values into colors via a lookup table
vtkLookupTable is an object that is used by mapper objects to map scalar values into RGBA (red-green-blue-alpha) color specification, or RGBA into scalar values. The color table can be created by direct insertion of color values, or by specifying a hue, saturation, value, and alpha range and generating a table.
A special color for NaN values in the data can be specified via SetNanColor(). In addition, a color for data values below the lookup table range minimum can be specified with SetBelowRangeColor(), and that color will be used for values below the range minimum when UseBelowRangeColor is on. Likewise, a color for data values above the lookup table range maximum can be specified with SetAboveRangeColor(), and it is used when UseAboveRangeColor is on.
This class behaves differently depending on how \a IndexedLookup is set. When true, vtkLookupTable enters a mode for representing categorical color maps. By setting \a IndexedLookup to true, you indicate that the annotated values are the only valid values for which entries in the color table should be returned. The colors in the lookup \a Table are assigned to annotated values by taking the modulus of their index in the list of annotations. \a IndexedLookup changes the behavior of \a GetIndex, which in turn changes the way \a MapScalarsThroughTable2 behaves; when \a IndexedLookup is true, \a MapScalarsThroughTable2 will search for scalar values in \a AnnotatedValues and use the resulting index to determine the color. If a scalar value is not present in \a AnnotatedValues, then \a NanColor will be used.
@warning You need to explicitly call Build() when constructing the LUT by hand.
@sa vtkLogLookupTable vtkWindowLevelLookupTable
Implementations
Sourceimpl vtkLookupTable
impl vtkLookupTable
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkLookupTable wrapped inside vtkNew