pub struct vtkObject(/* private fields */);Expand description
abstract base class for most VTK objects
vtkObject is the base class for most objects in the visualization toolkit. vtkObject provides methods for tracking modification time, debugging, printing, and event callbacks. Most objects created within the VTK framework should be a subclass of vtkObject or one of its children. The few exceptions tend to be very small helper classes that usually never get instantiated or situations where multiple inheritance gets in the way. vtkObject also performs reference counting: objects that are reference counted exist as long as another object uses them. Once the last reference to a reference counted object is removed, the object will spontaneously destruct.
@warning Note: in VTK objects should always be created with the New() method and deleted with the Delete() method. VTK objects cannot be allocated off the stack (i.e., automatic objects) because the constructor is a protected method.
@sa vtkCommand vtkTimeStamp