pub struct vtkPriorityQueue(/* private fields */);Expand description
a list of ids arranged in priority order
vtkPriorityQueue is a general object for creating and manipulating lists of object ids (e.g., point or cell ids). Object ids are sorted according to a user-specified priority, where entries at the top of the queue have the smallest values.
This implementation provides a feature beyond the usual ability to insert and retrieve (or pop) values from the queue. It is also possible to pop any item in the queue given its id number. This allows you to delete entries in the queue which can useful for reinserting an item into the queue.
@warning This implementation is a variation of the priority queue described in “Data Structures & Algorithms” by Aho, Hopcroft, Ullman. It creates a balanced, partially ordered binary tree implemented as an ordered array. This avoids the overhead associated with parent/child pointers, and frequent memory allocation and deallocation.
Implementations
Sourceimpl vtkPriorityQueue
impl vtkPriorityQueue
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPriorityQueue wrapped inside vtkNew