pub struct vtkSignedCharArray(/* private fields */);Expand description
dynamic, self-adjusting array of signed char
vtkSignedCharArray is an array of values of type signed char. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
Implementations
Sourceimpl vtkSignedCharArray
impl vtkSignedCharArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkSignedCharArray wrapped inside vtkNew