pub struct vtkStringArray(/* private fields */);Expand description
a vtkAbstractArray subclass for strings
Points and cells may sometimes have associated data that are stored as strings, e.g. labels for information visualization projects. This class provides a clean way to store and access those strings. @par Thanks: Andy Wilson (atwilso@sandia.gov) wrote this class.
Implementations
Sourceimpl vtkStringArray
impl vtkStringArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkStringArray wrapped inside vtkNew