pub struct vtkUnsignedIntArray(/* private fields */);Expand description
dynamic, self-adjusting array of unsigned int
vtkUnsignedIntArray is an array of values of type unsigned int. It provides methods for insertion and retrieval of values and will automatically resize itself to hold new data.
The C++ standard does not define the exact size of the unsigned int type, so use of this type directly is discouraged. If an array of 32 bit unsigned integers is needed, prefer vtkTypeUInt32Array to this class.
Implementations
Sourceimpl vtkUnsignedIntArray
impl vtkUnsignedIntArray
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUnsignedIntArray wrapped inside vtkNew