vtkAnnulus

Struct vtkAnnulus 

pub struct vtkAnnulus(/* private fields */);
implicit function for a annulus

vtkAnnulus computes the implicit function and function gradient for an annulus composed of two co-axial cylinders. vtkAnnulus is a concrete implementation of vtkImplicitFunction. By default the Annulus is centered at the origin and the axis of rotation is along the y-axis. You can redefine the center and axis of rotation by setting the Center and Axis data members. (Note that it is also possible to use the superclass’ vtkImplicitFunction transformation matrix if necessary to reposition by using FunctionValue() and FunctionGradient().)

@warning The annulus is infinite in extent. To truncate the annulus in modeling operations use the vtkImplicitBoolean in combination with clipping planes.

Implementations

Source

impl vtkAnnulus

pub fn new() -> Self

Creates a new vtkAnnulus wrapped inside vtkNew