pub struct vtkBSPCuts(/* private fields */);Expand description
This class represents an axis-aligned Binary Spatial
Partitioning of a 3D space.
This class converts between the vtkKdTree representation of a tree of vtkKdNodes (used by vtkDistributedDataFilter) and a compact array representation that might be provided by a graph partitioning library like Zoltan. Such a representation could be used in message passing.
@sa vtkKdTree vtkKdNode vtkDistributedDataFilter
Implementations
Sourceimpl vtkBSPCuts
impl vtkBSPCuts
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkBSPCuts wrapped inside vtkNew