pub struct vtkBiQuadraticQuadraticWedge(/* private fields */);Expand description
cell represents a parabolic, 18-node isoparametric wedge
vtkBiQuadraticQuadraticWedge is a concrete implementation of vtkNonLinearCell to represent a three-dimensional, 18-node isoparametric biquadratic wedge. The interpolation is the standard finite element, biquadratic-quadratic isoparametric shape function plus the linear functions. The cell includes a mid-edge node. The ordering of the 18 points defining the cell is point ids (0-5,6-15, 16-18) where point ids 0-5 are the six corner vertices of the wedge; followed by nine midedge nodes (6-15) and 3 center-face nodes. Note that these midedge nodes correspond lie on the edges defined by (0,1), (1,2), (2,0), (3,4), (4,5), (5,3), (0,3), (1,4), (2,5), and the center-face nodes are laying in quads 16-(0,1,4,3), 17-(1,2,5,4) and (2,0,3,5).
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticQuad vtkQuadraticPyramid
@par Thanks: Thanks to Soeren Gebbert who developed this class and integrated it into VTK 5.0.
Implementations
Sourceimpl vtkBiQuadraticQuadraticWedge
impl vtkBiQuadraticQuadraticWedge
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkBiQuadraticQuadraticWedge wrapped inside vtkNew