pub struct vtkCellGrid(/* private fields */);Expand description
Visualization data composed of cells of arbitrary type.
vtkCellGrid inherits vtkDataObject in order to introduce the concept of cells that, instead of relying on spatial points to specify their shape, rely on degrees of freedom (which may or may not be embedded in a world coordinate system).
The degrees of freedom that define cells and the functions using those cells as their domain are provided in data arrays. The arrays are partitioned into groups (vtkDataSetAttributes) by the registered cell types. Each array in a group has the same number of tuples.
@sa vtkDataObject vtkDataSetAttributes
Implementations
Sourceimpl vtkCellGrid
impl vtkCellGrid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellGrid wrapped inside vtkNew