pub struct vtkCellGridResponders(/* private fields */);Expand description
A container that holds objects able to respond to queries
specialized for particular vtkCellMetadata types.
This class holds sets of responders for vtkCellGridQuery and for vtkCellAttributeQuery.
Cell-grid query responders
vtkCellGridResponders holds a list of objects statically registered to the vtkCellMetadata subclass. These objects respond to queries for information (e.g., a bounding box) or processing (e.g., rendering, picking, generating isocontours) for one cell type (and subclasses of that cell type if no more specific responder is registered).
Application code (such as a plugin) can register subclasses of vtkCellGridResponse which accept the API of a particular vtkCellGridQuery for that cell type. Then, when a query is passed to the cell, this collection will identify matching responders for the query and invoke them until one returns true (indicating success). Multiple matches can exist as a responder can be registered to a common base cell class and/or to handle common base query classes.
If a given cell type cannot respond to a query, its superclasses are asked to respond. If no superclass can respond to the query, then query’s superclasses are searched for responders.
Because queries can be registered to cell types at any time, existing cell types can be extended to support new features by additional libraries.
Cell-attribute calculators
In order to support the evaluation of vtkCellAttribute data on any vtkCellMetadata (cell type), this class also holds “calculators” grouped by both attribute and cell type. This API is different that vtkCellGridQuery because vtkCellAttribute is not subclassed by attribute type but rather uses vtkStringToken data to determine the nature of the attribute (e.g., Lagrange; Nedelec; Raviart-Thomas; etc.).
It is also different in that these objects are expected to be used inside vtkCellGridQuery to evaluate a single cell at a time rather than longer-running queries across all cells.
@sa vtkCellMetadata vtkCellGrid vtkCellAttribute
Implementations
Sourceimpl vtkCellGridResponders
impl vtkCellGridResponders
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellGridResponders wrapped inside vtkNew