pub struct vtkCellTypes(/* private fields */);Expand description
object provides direct access to cells in vtkCellArray and type information
This class is a supplemental object to vtkCellArray to allow random access into cells as well as representing cell type information. The “location” field is the location in the vtkCellArray list in terms of an integer offset. An integer offset was used instead of a pointer for easy storage and inter-process communication. The type information is defined in the file vtkCellType.h.
@warning Sometimes this class is used to pass type information independent of the random access (i.e., location) information. For example, see vtkDataSet::GetCellTypes(). If you use the class in this way, you can use a location value of -1.
@sa vtkCellArray vtkCellLinks
Implementations
Sourceimpl vtkCellTypes
impl vtkCellTypes
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCellTypes wrapped inside vtkNew