vtkCone

Struct vtkCone 

pub struct vtkCone(/* private fields */);
implicit function for a cone

vtkCone computes the implicit function and function gradient for a cone. vtkCone is a concrete implementation of vtkImplicitFunction. By default, the cone vertex is located at the origin with axis of rotation coincident with x-axis. You can use the superclass’ vtkImplicitFunction transformation matrix to reposition. You can alternatively use the accessors provided by this class, which will cause the transform to be recomputed. to reposition/orient the cone. The angle specifies the angle between the axis of rotation and the side of the cone.

@warning The cone is infinite in extent (on both sides if IsDoubleCone is set to true). To truncate the cone use the vtkImplicitBoolean in combination with clipping planes.

Implementations

Source

impl vtkCone

pub fn new() -> Self

Creates a new vtkCone wrapped inside vtkNew