pub struct vtkCoordinateFrame(/* private fields */);Expand description
implicit function for a right-handed coordinate system
vtkCoordinateFrame computes an implicit function and function gradient for a set of 3 orthogonal planes.
The function evaluates to a combination of quartic spherical harmonic basis functions: \f$\sqrt(\frac{7}{12})*Y_{4,0} + \sqrt(\frac{5}{12})*Y_{4,4}\f$ that – when evaluated on a unit sphere centered at the coordinate frame’s origin – form a 6-lobed function with a maximum along each of the 6 axes (3 positive, 3 negative). This function is frequently used in frame-field design.
See the paper “On Smooth Frame Field Design” by Nicolas Ray and Dmitry Sokolov (2016, hal-01245657, https://hal.inria.fr/hal-01245657/file/framefield.pdf ) for more information.
Implementations
Sourceimpl vtkCoordinateFrame
impl vtkCoordinateFrame
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCoordinateFrame wrapped inside vtkNew