pub struct vtkEdgeListIterator(/* private fields */);Expand description
Iterates through all edges in a graph.
vtkEdgeListIterator iterates through all the edges in a graph, by traversing the adjacency list for each vertex. You may instantiate this class directly and call SetGraph() to traverse a certain graph. You may also call the graph’s GetEdges() method to set up the iterator for a certain graph.
Note that this class does NOT guarantee that the edges will be processed in order of their ids (i.e. it will not necessarily return edge 0, then edge 1, etc.).
@sa vtkGraph
Implementations
Sourceimpl vtkEdgeListIterator
impl vtkEdgeListIterator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkEdgeListIterator wrapped inside vtkNew