pub struct vtkEdgeTable(/* private fields */);Expand description
keep track of edges (edge is pair of integer id’s)
vtkEdgeTable is a general object for keeping track of lists of edges. An edge is defined by the pair of point id’s (p1,p2). Methods are available to insert edges, check if edges exist, and traverse the list of edges. Also, it’s possible to associate attribute information with each edge. The attribute information may take the form of vtkIdType id’s, void* pointers, or points. To store attributes, make sure that InitEdgeInsertion() is invoked with the storeAttributes flag set properly. If points are inserted, use the methods InitPointInsertion() and InsertUniquePoint().
Implementations
Sourceimpl vtkEdgeTable
impl vtkEdgeTable
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkEdgeTable wrapped inside vtkNew