pub struct vtkGenericEdgeTable(/* private fields */);Expand description
keep track of edges (defined by pair of integer id’s)
vtkGenericEdgeTable is used to indicate the existence of and hold information about edges. Similar to vtkEdgeTable, this class is more sophisticated in that it uses reference counting to keep track of when information about an edge should be deleted.
vtkGenericEdgeTable is a helper class used in the adaptor framework. It is used during the tessellation process to hold information about the error metric on each edge. This avoids recomputing the error metric each time the same edge is visited.
Implementations
Sourceimpl vtkGenericEdgeTable
impl vtkGenericEdgeTable
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkGenericEdgeTable wrapped inside vtkNew