pub struct vtkGenericInterpolatedVelocityField(/* private fields */);Expand description
Interface for obtaining
interpolated velocity values
vtkGenericInterpolatedVelocityField acts as a continuous velocity field by performing cell interpolation on the underlying vtkDataSet. This is a concrete sub-class of vtkFunctionSet with NumberOfIndependentVariables = 4 (x,y,z,t) and NumberOfFunctions = 3 (u,v,w). Normally, every time an evaluation is performed, the cell which contains the point (x,y,z) has to be found by calling FindCell. This is a computationally expansive operation. In certain cases, the cell search can be avoided or shortened by providing a guess for the cell iterator. For example, in streamline integration, the next evaluation is usually in the same or a neighbour cell. For this reason, vtkGenericInterpolatedVelocityField stores the last cell iterator. If caching is turned on, it uses this iterator as the starting point.
@warning vtkGenericInterpolatedVelocityField is not thread safe. A new instance should be created by each thread.
@sa vtkFunctionSet vtkGenericStreamTracer
Implementations
Sourceimpl vtkGenericInterpolatedVelocityField
impl vtkGenericInterpolatedVelocityField
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkGenericInterpolatedVelocityField wrapped inside vtkNew