vtkGraphEdge

Struct vtkGraphEdge 

pub struct vtkGraphEdge(/* private fields */);
Representation of a single graph edge.

A heavy-weight (vtkObject subclass) graph edge object that may be used instead of the vtkEdgeType struct, for use with wrappers. The edge contains the source and target vertex ids, and the edge id.

@sa vtkGraph

Implementations

Source

impl vtkGraphEdge

pub fn new() -> Self

Creates a new vtkGraphEdge wrapped inside vtkNew