pub struct vtkHexagonalPrism(/* private fields */);Expand description
a 3D cell that represents a prism with
hexagonal base
vtkHexagonalPrism is a concrete implementation of vtkCell to represent a linear 3D prism with hexagonal base. Such prism is defined by the twelve points (0-12) where (0,1,2,3,4,5) is the base of the prism which, using the right hand rule, forms a hexagon whose normal points is in the direction of the opposite face (6,7,8,9,10,11).
@par Thanks: Thanks to Philippe Guerville who developed this class. Thanks to Charles Pignerol (CEA-DAM, France) who ported this class under VTK 4. Thanks to Jean Favre (CSCS, Switzerland) who contributed to integrate this class in VTK. Please address all comments to Jean Favre (jfavre at cscs.ch).
Implementations
Sourceimpl vtkHexagonalPrism
impl vtkHexagonalPrism
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkHexagonalPrism wrapped inside vtkNew