pub struct vtkHyperTreeGridGeometricLocator(/* private fields */);Expand description
class that implements accelerated searches through HyperTree Grids (HTGs) using geometric
information
The goal of this class is to implement a geometric locator search through the HTG structure. Its main feature should be to expose a generic interface to finding the HTG cells that contain a given geometric object. The search through the HTG is implemented using a vtkHyperTreeGridNonOrientedGeometricCursor. The arborescent structure of the HTG should be sufficient to accelerate the search and achieve good performance in general.
All methods in this class should be thread safe since it is meant to be used in a multi-threaded environment out of the box (except SetHTG which should be called outside any multi-threaded setting).
@sa vtkHyperTreeGridLocator, vtkHyperTreeGrid, vtkHyperTree, vtkHyperTreeGridOrientedCursor, vtkHyperTreeGridNonOrientedCursor
Implementations
Sourceimpl vtkHyperTreeGridGeometricLocator
impl vtkHyperTreeGridGeometricLocator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkHyperTreeGridGeometricLocator wrapped inside vtkNew