pub struct vtkHyperTreeGridNonOrientedUnlimitedMooreSuperCursor(/* private fields */);Expand description
Specific Moore super cursor that can subdivied neighborhood
This supercursor behave like the Moore supercursor but relies on the vtkHyperTreeGridNonOrientedUnlimitedSuperCursor so the neighborhood can be refined to reach the level of the current cell in any case.
@sa vtkHyperTree vtkHyperTreeGrid vtkHyperTreeGridNonOrientedMooreSuperCursor
Implementations
Sourceimpl vtkHyperTreeGridNonOrientedUnlimitedMooreSuperCursor
impl vtkHyperTreeGridNonOrientedUnlimitedMooreSuperCursor
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkHyperTreeGridNonOrientedUnlimitedMooreSuperCursor wrapped inside vtkNew