pub struct vtkImageTransform(/* private fields */);Expand description
helper class to transform output of non-axis-aligned images
vtkImageTransform is a helper class to transform the output of image filters (i.e., filter that input vtkImageData) by applying the Index to Physical transformation from the input image, which can include origin, spacing, direction. The transformation process is threaded with vtkSMPTools for performance.
Typically in application the single method TransformPointSet() is invoked to transform the output of an image algorithm (assuming that the image’s direction/orientation matrix is non-identity). Note that vtkPointSets encompass vtkPolyData as well as vtkUnstructuredGrids. In the future other output types may be added. Note that specific methods for transforming points, normals, and vectors is also provided by this class in case additional output data arrays need to be transformed (since TransformPointSet() only processes data arrays labeled as points, normals, and vectors).
@warning This class assumes that any vectors are gradients, and vector arrays will therefore be transformed by first dividing by the spacing and then applying the inverse transpose of the direction matrix.
@warning This class has been threaded with vtkSMPTools. Using TBB or other non-sequential type (set in the CMake variable VTK_SMP_IMPLEMENTATION_TYPE) may improve performance significantly.
Implementations
Sourceimpl vtkImageTransform
impl vtkImageTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkImageTransform wrapped inside vtkNew