pub struct vtkImplicitDataSet(/* private fields */);Expand description
treat a dataset as if it were an implicit function
vtkImplicitDataSet treats any type of dataset as if it were an implicit function. This means it computes a function value and gradient. vtkImplicitDataSet is a concrete implementation of vtkImplicitFunction.
vtkImplicitDataSet computes the function (at the point x) by performing cell interpolation. That is, it finds the cell containing x, and then uses the cell’s interpolation functions to compute an interpolated scalar value at x. (A similar approach is used to find the gradient, if requested.) Points outside of the dataset are assigned the value of the ivar OutValue, and the gradient value OutGradient.
@warning Any type of dataset can be used as an implicit function as long as it has scalar data associated with it.
@sa vtkImplicitFunction vtkImplicitVolume vtkClipPolyData vtkCutter vtkImplicitWindowFunction
Implementations
Sourceimpl vtkImplicitDataSet
impl vtkImplicitDataSet
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkImplicitDataSet wrapped inside vtkNew