pub struct vtkImplicitVolume(/* private fields */);Expand description
treat a volume as if it were an implicit function
vtkImplicitVolume treats a volume (e.g., structured point dataset) as if it were an implicit function. This means it computes a function value and gradient. vtkImplicitVolume is a concrete implementation of vtkImplicitFunction.
vtkImplicitDataSet computes the function (at the point x) by performing cell interpolation. That is, it finds the cell containing x, and then uses the cell’s interpolation functions to compute an interpolated scalar value at x. (A similar approach is used to find the gradient, if requested.) Points outside of the dataset are assigned the value of the ivar OutValue, and the gradient value OutGradient.
@warning The input volume data is only updated when GetMTime() is called. Works for 3D structured points datasets, 0D-2D datasets won’t work properly.
@sa vtkImplicitFunction vtkImplicitDataSet vtkClipPolyData vtkCutter vtkImplicitWindowFunction
Implementations
Sourceimpl vtkImplicitVolume
impl vtkImplicitVolume
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkImplicitVolume wrapped inside vtkNew