pub struct vtkImplicitWindowFunction(/* private fields */);Expand description
implicit function maps another implicit function to lie within a specified range
vtkImplicitWindowFunction is used to modify the output of another implicit function to lie within a specified “window”, or function range. This can be used to add “thickness” to cutting or clipping functions.
This class works as follows. First, it evaluates the function value of the user-specified implicit function. Then, based on the window range specified, it maps the function value into the window values specified.
@sa vtkImplicitFunction
Implementations
Sourceimpl vtkImplicitWindowFunction
impl vtkImplicitWindowFunction
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkImplicitWindowFunction wrapped inside vtkNew