pub struct vtkIncrementalOctreePointLocator(/* private fields */);Expand description
Incremental octree in support
of both point location and point insertion.
As opposed to the uniform bin-based search structure (adopted in class vtkPointLocator) with a fixed spatial resolution, an octree mechanism employs a hierarchy of tree-like sub-division of the 3D data domain. Thus it enables data-aware multi-resolution and accordingly accelerated point location as well as insertion, particularly when handling a radically imbalanced layout of points as not uncommon in datasets defined on adaptive meshes. Compared to a static point locator supporting pure location functionalities through some search structure established from a fixed set of points, an incremental point locator allows for, in addition, point insertion capabilities, with the search structure maintaining a dynamically increasing number of points. Class vtkIncrementalOctreePointLocator is an octree-based accelerated implementation of the functionalities of the uniform bin-based incremental point locator vtkPointLocator. For point location, an octree is built by accessing a vtkDataSet, specifically a vtkPointSet. For point insertion, an empty octree is inited and then incrementally populated as points are inserted. Three increasingly complex point insertion modes, i.e., direct check-free insertion, zero tolerance insertion, and non-zero tolerance insertion, are supported. In fact, the octree used in the point location mode is actually constructed via direct check-free point insertion. This class also provides a polygonal representation of the octree boundary.
@sa vtkAbstractPointLocator, vtkIncrementalPointLocator, vtkPointLocator, vtkMergePoints
Implementations
Sourceimpl vtkIncrementalOctreePointLocator
impl vtkIncrementalOctreePointLocator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkIncrementalOctreePointLocator wrapped inside vtkNew