vtkIterativeClosestPointTransform

Struct vtkIterativeClosestPointTransform 

pub struct vtkIterativeClosestPointTransform(/* private fields */);
Implementation of the ICP algorithm.

Match two surfaces using the iterative closest point (ICP) algorithm. The core of the algorithm is to match each vertex in one surface with the closest surface point on the other, then apply the transformation that modify one surface to best match the other (in a least square sense). This has to be iterated to get proper convergence of the surfaces. @attention Use vtkTransformPolyDataFilter to apply the resulting ICP transform to your data. You might also set it to your actor’s user transform. @attention This class makes use of vtkLandmarkTransform internally to compute the best fit. Use the GetLandmarkTransform member to get a pointer to that transform and set its parameters. You might, for example, constrain the number of degrees of freedom of the solution (i.e. rigid body, similarity, etc.) by checking the vtkLandmarkTransform documentation for its SetMode member. @sa vtkLandmarkTransform

Implementations

Source

impl vtkIterativeClosestPointTransform

pub fn new() -> Self

Creates a new vtkIterativeClosestPointTransform wrapped inside vtkNew