pub struct vtkLagrangeTetra(/* private fields */);Expand description
A 3D cell that represents an arbitrary order Lagrange tetrahedron
vtkLagrangeTetra is a concrete implementation of vtkCell to represent a 3D tetrahedron using Lagrange shape functions of user specified order.
The number of points in a Lagrange cell determines the order over which they are iterated relative to the parametric coordinate system of the cell. The first points that are reported are vertices. They appear in the same order in which they would appear in linear cells. Mid-edge points are reported next. They are reported in sequence. For two- and three-dimensional (3D) cells, the following set of points to be reported are face points. Finally, 3D cells report points interior to their volume.
Implementations
Sourceimpl vtkLagrangeTetra
impl vtkLagrangeTetra
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkLagrangeTetra wrapped inside vtkNew