pub struct vtkLagrangeWedge(/* private fields */);Expand description
A 3D cell that represents an arbitrary order Lagrange wedge
vtkLagrangeWedge is a concrete implementation of vtkCell to represent a 3D wedge using Lagrange shape functions of user specified order. A wedge consists of two triangular and three quadrilateral faces. The first six points of the wedge (0-5) are the “corner” points where the first three points are the base of the wedge. This wedge point ordering is opposite the vtkWedge ordering though in that the base of the wedge defined by the first three points (0,1,2) form a triangle whose normal points inward (toward the triangular face (3,4,5)). While this is opposite the vtkWedge convention it is consistent with every other cell type in VTK. The first 2 parametric coordinates of the Lagrange wedge or for the triangular base and vary between 0 and 1. The third parametric coordinate is between the two triangular faces and goes from 0 to 1 as well.
Implementations
Sourceimpl vtkLagrangeWedge
impl vtkLagrangeWedge
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkLagrangeWedge wrapped inside vtkNew