pub struct vtkOctreePointLocatorNode(/* private fields */);Expand description
Octree node that has 8 children each of equal size
This class represents a single spatial region in a 3D axis octant partitioning. It is intended to work efficiently with the vtkOctreePointLocator and is not meant for general use. It is assumed the region bounds some set of points. The ordering of the children is (-x,-y,-z),(+x,-y,-z),(-x,+y,-z),(+x,+y,-z),(-x,-y,+z),(+x,-y,+z), (-x,+y,+z),(+x,+y,+z). The portion of the domain assigned to an octant is Min < x <= Max.
@sa vtkOctreePointLocator
Implementations
Sourceimpl vtkOctreePointLocatorNode
impl vtkOctreePointLocatorNode
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkOctreePointLocatorNode wrapped inside vtkNew