pub struct vtkPartitionedDataSetCollection(/* private fields */);Expand description
Composite dataset that groups datasets as a collection.
vtkPartitionedDataSetCollection is a vtkCompositeDataSet that stores a collection of non-null vtkPartitionedDataSets. These items can represent different concepts depending on the context. For example, they can represent region of different materials in a simulation or parts in an assembly. It is not requires that items have anything in common. For example, they can have completely different point or cell arrays.
Implementations
Sourceimpl vtkPartitionedDataSetCollection
impl vtkPartitionedDataSetCollection
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPartitionedDataSetCollection wrapped inside vtkNew