pub struct vtkPlanesIntersection(/* private fields */);Expand description
A vtkPlanesIntersection object is a
vtkPlanes object that can compute whether the arbitrary convex region bounded by it’s planes intersects an axis-aligned box.
A subclass of vtkPlanes, this class determines whether it intersects an axis aligned box. This is motivated by the need to intersect the axis aligned region of a spatial decomposition of volume data with various other regions. It uses the algorithm from Graphics Gems IV, page 81.
@par Caveat: An instance of vtkPlanes can be redefined by changing the planes, but this subclass then will not know if the region vertices are up to date. (Region vertices can be specified in SetRegionVertices or computed by the subclass.) So Delete and recreate if you want to change the set of planes.
Implementations
Sourceimpl vtkPlanesIntersection
impl vtkPlanesIntersection
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPlanesIntersection wrapped inside vtkNew