pub struct vtkPointSet(/* private fields */);Expand description
concrete class for storing a set of points
vtkPointSet is an concrete class representing a set of points that specifies the interface for datasets that explicitly use “point” arrays to represent geometry. For example, vtkPolyData, vtkUnstructuredGrid, and vtkStructuredGrid require point arrays to specify point positions, while vtkImageData represents point positions implicitly (and hence is not a subclass of vtkImageData).
Note: The vtkPolyData and vtkUnstructuredGrid datasets (derived classes of vtkPointSet) are often used in geometric computation (e.g., vtkDelaunay2D). In most cases during filter execution the output geometry and/or topology is created once and provided as output; however in a very few cases the underlying geometry/topology may be created and then incrementally modified. This has implications on the use of supporting classes like locators and cell links topological structures which may be required to support incremental editing operations. Consequently, there is a flag, Editable, that controls whether the dataset can be incrementally edited after it is initially created. By default, and for performance reasons, vtkPointSet derived classes are created as non-editable. The few methods that require incremental editing capabilities are documented in derived classes.
Another important feature of vtkPointSet classes is the use of an internal locator to speed up certain operations like FindCell(). Depending on the application and desired performance, different locators (either a cell or point locator) of different locator types may be used, along with different strategies for using the locators to perform various operations. See the class vtkFindCellStrategy for more information
@sa vtkPolyData vtkStructuredGrid vtkUnstructuredGrid vtkFindCellStrategy
Implementations
Sourceimpl vtkPointSet
impl vtkPointSet
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkPointSet wrapped inside vtkNew