pub struct vtkQuadraticLinearQuad(/* private fields */);Expand description
cell represents a quadratic-linear, 6-node isoparametric quad
vtkQuadraticQuad is a concrete implementation of vtkNonLinearCell to represent a two-dimensional, 6-node isoparametric quadratic-linear quadrilateral element. The interpolation is the standard finite element, quadratic-linear isoparametric shape function. The cell includes a mid-edge node for two of the four edges. The ordering of the six points defining the cell are point ids (0-3,4-5) where ids 0-3 define the four corner vertices of the quad; ids 4-7 define the midedge nodes (0,1) and (2,3) .
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticQuad vtkQuadraticHexahedron vtkQuadraticWedge vtkQuadraticPyramid
@par Thanks: Thanks to Soeren Gebbert who developed this class and integrated it into VTK 5.0.
Implementations
Sourceimpl vtkQuadraticLinearQuad
impl vtkQuadraticLinearQuad
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticLinearQuad wrapped inside vtkNew