pub struct vtkQuadraticLinearWedge(/* private fields */);Expand description
cell represents a, 12-node isoparametric wedge
vtkQuadraticLinearWedge is a concrete implementation of vtkNonLinearCell to represent a three-dimensional, 12-node isoparametric linear quadratic wedge. The interpolation is the standard finite element, quadratic isoparametric shape function in xy - layer and the linear functions in z - direction. The cell includes mid-edge node in the triangle edges. The ordering of the 12 points defining the cell is point ids (0-5,6-12) where point ids 0-5 are the six corner vertices of the wedge; followed by six midedge nodes (6-12). Note that these midedge nodes correspond lie on the edges defined by (0,1), (1,2), (2,0), (3,4), (4,5), (5,3). The Edges (0,3), (1,4), (2,5) don’t have midedge nodes.
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticQuad vtkQuadraticPyramid
@par Thanks: Thanks to Soeren Gebbert who developed this class and integrated it into VTK 5.0.
Implementations
Sourceimpl vtkQuadraticLinearWedge
impl vtkQuadraticLinearWedge
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticLinearWedge wrapped inside vtkNew