pub struct vtkQuadraticPyramid(/* private fields */);Expand description
cell represents a parabolic, 13-node isoparametric pyramid
vtkQuadraticPyramid is a concrete implementation of vtkNonLinearCell to represent a three-dimensional, 13-node isoparametric parabolic pyramid. The interpolation is the standard finite element, quadratic isoparametric shape function. The cell includes a mid-edge node. The ordering of the thirteen points defining the cell is point ids (0-4,5-12) where point ids 0-4 are the five corner vertices of the pyramid; followed by eight midedge nodes (5-12). Note that these midedge nodes lie on the edges defined by (0,1), (1,2), (2,3), (3,0), (0,4), (1,4), (2,4), (3,4), respectively. The parametric location of vertex #4 is [0, 0, 1].
@sa vtkQuadraticEdge vtkQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkQuadraticQuad vtkQuadraticWedge
@par Thanks: The shape functions and derivatives could be implemented thanks to the report Pyramid Solid Elements Linear and Quadratic Iso-P Models From Center For Aerospace Structures
Implementations
Sourceimpl vtkQuadraticPyramid
impl vtkQuadraticPyramid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuadraticPyramid wrapped inside vtkNew