pub struct vtkSimpleCellTessellator(/* private fields */);Expand description
helper class to perform cell tessellation
vtkSimpleCellTessellator is a helper class to perform adaptive tessellation of particular cell topologies. The major purpose for this class is to transform higher-order cell types (e.g., higher-order finite elements) into linear cells that can then be easily visualized by VTK. This class works in conjunction with the vtkGenericDataSet and vtkGenericAdaptorCell classes.
This algorithm is based on edge subdivision. An error metric along each edge is evaluated, and if the error is greater than some tolerance, the edge is subdivided (as well as all connected 2D and 3D cells). The process repeats until the error metric is satisfied. Since the algorithm is based on edge subdivision it inherently avoid T-junctions.
A significant issue addressed by this algorithm is to ensure face compatibility across neighboring cells. That is, diagonals due to face triangulation must match to ensure that the mesh is compatible. The algorithm employs a precomputed table to accelerate the tessellation process. The table was generated with the help of vtkOrderedTriangulator the basic idea is that the choice of diagonal is made only by considering the relative value of the point ids.
@sa vtkGenericCellTessellator vtkGenericSubdivisionErrorMetric vtkAttributesErrorMetric vtkGeometricErrorMetric vtkViewDependentErrorMetric
Implementations
Sourceimpl vtkSimpleCellTessellator
impl vtkSimpleCellTessellator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkSimpleCellTessellator wrapped inside vtkNew