vtkSmoothErrorMetric

Struct vtkSmoothErrorMetric 

pub struct vtkSmoothErrorMetric(/* private fields */);
Objects that compute

geometry-based error during cell tessellation according to some max angle.

It is a concrete error metric, based on a geometric criterium: a max angle between the chord passing through the midpoint and one of the endpoints and the other chord passing through the midpoint and the other endpoint of the edge. It is related to the flatness of an edge.

@sa vtkGenericCellTessellator vtkGenericSubdivisionErrorMetric

Implementations

Source

impl vtkSmoothErrorMetric

pub fn new() -> Self

Creates a new vtkSmoothErrorMetric wrapped inside vtkNew