pub struct vtkSortFieldData(/* private fields */);Expand description
provides a method for sorting field data
vtkSortFieldData is used to sort data, based on its value, or with an associated key, into either ascending or descending order. This is useful for operations like selection, or analysis, when evaluating and processing data.
This class, which extends the base functionality of vtkSortDataArray, is used to sort field data and its various subclasses (vtkFieldData, vtkDataSetAttributes, vtkPointData, vtkCellData, etc.)
@warning This class has been threaded with vtkSMPTools. Using TBB or other non-sequential type (set in the CMake variable VTK_SMP_IMPLEMENTATION_TYPE) may improve performance significantly on multi-core machines.
@warning The sort methods below are static, hence the sorting methods can be used without instantiating the class. All methods are thread safe.
@sa vtkSortDataArray
Implementations
Sourceimpl vtkSortFieldData
impl vtkSortFieldData
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkSortFieldData wrapped inside vtkNew