pub struct vtkStaticCellLinks(/* private fields */);Expand description
object represents upward pointers from points
to list of cells using each point
vtkStaticCellLinks is a supplemental object to vtkCellArray and vtkCellTypes, enabling access from points to the cells using the points. vtkStaticCellLinks is an array of links, each link represents a list of cell ids using a particular point. The information provided by this object can be used to determine cell neighbors and construct other local topological information. This class is a faster implementation of vtkCellLinks. However, it cannot be incrementally constructed; it is meant to be constructed once (statically) and must be rebuilt if the cells change.
@warning This is a drop-in replacement for vtkCellLinks using static link construction. It uses the templated vtkStaticCellLinksTemplate class, instantiating vtkStaticCellLinksTemplate with a vtkIdType template parameter. Note that for best performance, the vtkStaticCellLinksTemplate class may be used directly, instantiating it with the appropriate id type. This class is also wrappable and can be used from an interpreted language such as Python.
@sa vtkCellLinks vtkStaticCellLinksTemplate
Implementations
Sourceimpl vtkStaticCellLinks
impl vtkStaticCellLinks
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkStaticCellLinks wrapped inside vtkNew