pub struct vtkTable(/* private fields */);Expand description
A table, which contains similar-typed columns of data
vtkTable is a basic data structure for storing columns of data. Internally, columns are stored in a vtkDataSetAttributes structure called RowData. However, using the vtkTable API additionally ensures that every column has the same number of entries, and provides row access (using vtkVariantArray) and single entry access (using vtkVariant).
Inserting or removing rows via the class API preserves existing table data where possible.
The “RemoveRow*” and SetNumberOfRows() operations will not release memory. Call on SqueezeRows() to achieve this after performing the operations.
The field data inherited from vtkDataObject may be used to store metadata related to the table.
@warning You should use the vtkTable API to change the table data. Performing operations on the object returned by GetRowData() may yield unexpected results. vtkTable does allow the user to set the field data using SetRowData(); the number of rows in the table is determined by the number of tuples in the first array (it is assumed that all arrays are the same length).
@warning Each column added with AddColumn must have its name set to a unique, non-empty string in order for GetValue() to function properly.
@par Thanks: Thanks to Patricia Crossno, Ken Moreland, Andrew Wilson and Brian Wylie from Sandia National Laboratories for their help in developing this class API.