pub struct vtkTriQuadraticPyramid(/* private fields */);Expand description
cell represents a parabolic, 19-node isoparametric pyramid
vtkTriQuadraticPyramid is a concrete implementation of vtkNonLinearCell to represent a second order three-dimensional isoparametric 19-node pyramid. The interpolation is the standard finite element, tri-quadratic isoparametric shape function. The cell includes 5 corner nodes, 8 mid-edge nodes, 5 mid-face nodes, and 1 volumetric centroid node. The ordering of the nineteen points defining the cell is point ids (0-4, 5-12, 13-17, 18), where point ids 0-4 are the five corner vertices of the pyramid; followed by 8 mid-edge nodes (5-12); followed by 5 mid-face nodes (13-17), and the last node (19) is the volumetric centroid node. Note that these mid-edge nodes lie on the edges defined by (0, 1), (1, 2), (2, 3), (3, 0), (0, 4), (1, 4), (2, 4), (3, 4), respectively. The mid-face nodes lie on the faces defined by (first corner nodes id’s, then mid-edge node id’s): quadrilateral face: (0, 3, 2, 1, 8, 7, 6, 5), triangle face 1: (0, 1, 4, 5, 10, 9), triangle face 2: (1, 2, 4, 6, 11, 10), triangle face 3: (2, 3, 4, 7, 12, 11), triangle face 5: (3, 0, 4, 8, 9, 12). The last point lies in the center of the cell (0, 1, 2, 3, 4). The parametric location of vertex #4 is [0.5, 0.5, 1].
@note It should be noted that the parametric coordinates that describe this cell are not distorted like in vtkPyramid and vtkQuadraticPyramid, which are a collapsed hexahedron. They are the actual uniform isoparametric coordinates, which are described in Browning’s dissertation (see thanks section), but they are converted to [0, 1] space, and the nodes are rotated so that node-0 has x = 0, y = 0, while maintaining the CCW order.
\verbatim Description of 19-node pyramid from bottom to top (based on the z-axis).
base quadrilateral including mid-edge nodes and mid-face node: 3– 7–2 | | 8 13 6 | | 0– 5–1
volumetric centroid node:
18
mid-face nodes of triangular faces:
16
/
17 15
\ /
14
mid-edge nodes of triangular faces:
12–11 | | 9–10
top corner(apex):
4
\endverbatim
@sa vtkQuadraticEdge vtkBiQuadraticTriangle vtkQuadraticTetra vtkQuadraticHexahedron vtkBiQuadraticQuad vtkQuadraticWedge
@par Thanks: The shape functions and derivatives could be implemented thanks to the doctoral dissertation: R.S. Browning. A Second-Order 19-Node Pyramid Finite Element Suitable for Lumped Mass Explicit Dynamic methods in Nonlinear Solid Mechanics, University of Alabama at Birmingham.
Implementations
Sourceimpl vtkTriQuadraticPyramid
impl vtkTriQuadraticPyramid
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTriQuadraticPyramid wrapped inside vtkNew