pub struct vtkUndirectedGraph(/* private fields */);Expand description
An undirected graph.
vtkUndirectedGraph is a collection of vertices along with a collection of undirected edges (they connect two vertices in no particular order). ShallowCopy(), DeepCopy(), CheckedShallowCopy(), CheckedDeepCopy() accept instances of vtkUndirectedGraph and vtkMutableUndirectedGraph. GetOutEdges(v, it) and GetInEdges(v, it) return the same list of edges, which is the list of all edges which have a v as an endpoint. GetInDegree(v), GetOutDegree(v) and GetDegree(v) all return the full degree of vertex v.
vtkUndirectedGraph is read-only. To create an undirected graph, use an instance of vtkMutableUndirectedGraph, then you may set the structure to a vtkUndirectedGraph using ShallowCopy().
@sa vtkGraph vtkMutableUndirectedGraph
Implementations
Sourceimpl vtkUndirectedGraph
impl vtkUndirectedGraph
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUndirectedGraph wrapped inside vtkNew