Structs
- vtkAggregate
ToPartitioned Data SetCollection - Aggregate results in the vtkEndFor
- vtkAlgorithm
- Superclass for all sources, filters, and sinks in VTK.
- vtkAlgorithm
Output - Proxy object to connect input/output ports.
- vtkAnnotation
Layers Algorithm - Superclass for algorithms that produce only vtkAnnotationLayers as output
- vtkArray
Data Algorithm - Superclass for algorithms that produce
- vtkCached
Streaming Demand Driven Pipeline - vtkCachedStreamingDemandDrivenPipeline
- vtkCast
ToConcrete - works around type-checking limitations
- vtkCell
Grid Algorithm - Superclass for algorithms that produce only polydata as output
- vtkComposite
Data Pipeline - Executive supporting composite datasets.
- vtkComposite
Data SetAlgorithm - Superclass for algorithms that produce only vtkCompositeDataSet as output
- vtkData
Object Algorithm - Superclass for algorithms that produce only data object as output
- vtkData
SetAlgorithm - Superclass for algorithms that produce output of the same type as input
- vtkDemand
Driven Pipeline - Executive supporting on-demand execution.
- vtkDirected
Graph Algorithm - Superclass for algorithms that produce only directed graph as output
- vtkEnd
For - vtkEndFor define the end of the sub-pipeline to loop
- vtkEnsemble
Source - source that manages dataset ensembles
- vtkExplicit
Structured Grid Algorithm - Superclass for algorithms that produce only
- vtkExtentRCB
Partitioner - This method partitions a global extent to N partitions where N is a user
- vtkExtent
Splitter - Split an extent across other extents.
- vtkExtent
Translator - Generates a structured extent from unstructured.
- vtkFor
Each - Algorithm allowing to implement a for loop using the VTK pipeline and a sister filter
- vtkGraph
Algorithm - Superclass for algorithms that produce only graph as output
- vtkHierarchical
BoxData SetAlgorithm - superclass for algorithms that
- vtkImage
ToStructured Grid - a structured grid instance.
- vtkImage
ToStructured Points - Attaches image pipeline to VTK.
- vtkMolecule
Algorithm - Superclass for algorithms that operate on
- vtkMulti
Block Data SetAlgorithm - Superclass for algorithms that produce only vtkMultiBlockDataSet as output
- vtkMulti
Time Step Algorithm - Superclass for algorithms that would like to make multiple time requests
- vtkNon
OverlappingAMR Algorithm - produce vtkNonOverlappingAMR as output.
- vtkOverlappingAMR
Algorithm - A base class for all algorithms that take as input vtkOverlappingAMR and
- vtkPass
Input Type Algorithm - Superclass for algorithms that produce output of the same type as input
- vtkPiecewise
Function Algorithm - Superclass for algorithms that produce only piecewise function as output
- vtkPiecewise
Function Shift Scale - vtkPoint
SetAlgorithm - Superclass for algorithms that produce output of the same type as input
- vtkPoly
Data Algorithm - Superclass for algorithms that produce only polydata as output
- vtkProgress
Observer - Basic class to optionally replace vtkAlgorithm progress functionality.
- vtkRectilinear
Grid Algorithm - Superclass for algorithms that produce only rectilinear grid as output
- vtkSMP
Progress Observer - Progress observer that is thread safe
- vtkSelection
Algorithm - Superclass for algorithms that produce only Selection as output
- vtkSimple
Scalar Tree - organize data according to scalar values (used to accelerate contouring operations)
- vtkSpan
Space - organize data according to scalar span space
- vtkSphere
Tree - class to build and traverse sphere trees
- vtkStreaming
Demand Driven Pipeline - Executive supporting partial updates.
- vtkStructured
Grid Algorithm - Superclass for algorithms that produce only structured grid as output
- vtkTable
Algorithm - Superclass for algorithms that produce only vtkTables as output
- vtkThreaded
Composite Data Pipeline - Executive that works in parallel
- vtkTime
Range - vtkExecutionRange using time to dispatch in a vtkForEach sub-pipeline
- vtkTree
Algorithm - Superclass for algorithms that produce only Tree as output
- vtkTrivial
Consumer - Consumer to consume data off of a pipeline.
- vtkTrivial
Producer - Producer for stand-alone data objects.
- vtkUndirected
Graph Algorithm - Superclass for algorithms that produce undirected graph as output
- vtkUniform
GridAMR Algorithm - vtkUniformGridAMR as output.
- vtkUniform
Grid Partitioner - A concrete implementation of vtkMultiBlockDataSetAlgorithm that provides functionality for partitioning a uniform grid. The partitioning method that is used is Recursive Coordinate Bisection (RCB) where each time the longest dimension is split.
- vtkUnstructured
Grid Algorithm - Superclass for algorithms that produce only unstructured grid as output
- vtkUnstructured
Grid Base Algorithm - Superclass for algorithms that