pub struct vtkCompositeDataPipeline(/* private fields */);Expand description
Executive supporting composite datasets.
vtkCompositeDataPipeline is an executive that supports the processing of composite dataset. It supports algorithms that are aware of composite dataset as well as those that are not. Type checking is performed at run time. Algorithms that are not composite dataset-aware have to support all dataset types contained in the composite dataset. The pipeline execution can be summarized as follows:
-
REQUEST_INFORMATION: The producers have to provide information about the contents of the composite dataset in this pass. Sources that can produce more than one piece (note that a piece is different than a block; each piece consists of 0 or more blocks) should set CAN_HANDLE_PIECE_REQUEST.
-
REQUEST_UPDATE_EXTENT: This pass is identical to the one implemented in vtkStreamingDemandDrivenPipeline
-
REQUEST_DATA: This is where the algorithms execute. If the vtkCompositeDataPipeline is assigned to a simple filter, it will invoke the vtkStreamingDemandDrivenPipeline passes in a loop, passing a different block each time and will collect the results in a composite dataset. @sa vtkCompositeDataSet
Implementations
Sourceimpl vtkCompositeDataPipeline
impl vtkCompositeDataPipeline
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCompositeDataPipeline wrapped inside vtkNew