pub struct vtkExtentSplitter(/* private fields */);Expand description
Split an extent across other extents.
vtkExtentSplitter splits each input extent into non-overlapping sub-extents that are completely contained within other “source extents”. A source extent corresponds to some resource providing an extent. Each source extent has an integer identifier, integer priority, and an extent. The input extents are split into sub-extents according to priority, availability, and amount of overlap of the source extents. This can be used by parallel data readers to read as few piece files as possible.
Implementations
Sourceimpl vtkExtentSplitter
impl vtkExtentSplitter
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkExtentSplitter wrapped inside vtkNew