pub struct vtkMoleculeAlgorithm(/* private fields */);Expand description
Superclass for algorithms that operate on
vtkMolecules
vtkMoleculeAlgorithm is a convenience class to make writing algorithms easier. There are some assumptions and defaults made by this class you should be aware of. This class defaults such that your filter will have one input port and one output port. If that is not the case simply change it with SetNumberOfInputPorts etc. See this class constructor for the default. This class also provides a FillInputPortInfo method that by default says that all inputs will be vtkMolecules. If that isn’t the case then please override this method in your subclass. You should implement the subclass’s algorithm into RequestData( request, inputVec, outputVec).
Implementations
Sourceimpl vtkMoleculeAlgorithm
impl vtkMoleculeAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMoleculeAlgorithm wrapped inside vtkNew