pub struct vtkMultiTimeStepAlgorithm(/* private fields */);Expand description
Superclass for algorithms that would like to make multiple time requests
This class can be inherited by any algorithm that wishes to make multiple time requests upstream.
A subclass should override RequestUpdateExtent and use
vtkMultiTimeStepAlgorithm::UPDATE_TIME_STEPS key to indicate which
timesteps are to be requested. This class will then take care of executing
the upstream pipeline to obtain the requested timesteps.
Subclasses can then override Execute which is provided a vector of input
data objects corresponding to the requested timesteps.
In VTK 9.1 and earlier, subclasses overrode RequestData instead of
Execute. RequestData was passed a vtkMultiBlockDataSet with blocks corresponding
to the input timesteps. However, with addition of vtkPartitionedDataSet and
vtkPartitionedDataSetCollection in VTK 9.2, it is not possible to package all
input data types into a multiblock dataset. Hence, the method is deprecated
and only used when Execute is not overridden.
Implementations
Sourceimpl vtkMultiTimeStepAlgorithm
impl vtkMultiTimeStepAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkMultiTimeStepAlgorithm wrapped inside vtkNew