pub struct vtkSpanSpace(/* private fields */);Expand description
organize data according to scalar span space
This is a helper class used to accelerate contouring operations. Given an dataset, it organizes the dataset cells into a 2D binned space, with coordinate axes (scalar_min,scalar_max). This so-called span space can then be traversed quickly to find the cells that intersect a specified contour value.
This class has an API that supports both serial and parallel operation. The parallel API enables the using class to grab arrays (or batches) of cells that lie along a particular row in the span space. These arrays can then be processed separately or in parallel.
Learn more about span space in these two publications: 1) “A Near Optimal Isosorface Extraction Algorithm Using the Span Space.” Yarden Livnat et al. and 2) Isosurfacing in Span Space with Utmost Efficiency.“ Han-Wei Shen et al.
@sa vtkScalarTree vtkSimpleScalarTree
Implementations
Sourceimpl vtkSpanSpace
impl vtkSpanSpace
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkSpanSpace wrapped inside vtkNew