vtkSphereTree

Struct vtkSphereTree 

pub struct vtkSphereTree(/* private fields */);
class to build and traverse sphere trees

vtkSphereTree is a helper class used to build and traverse sphere trees. Various types of trees can be constructed for different VTK dataset types, as well well as different approaches to organize the tree into hierarchies.

Typically building a complete sphere tree consists of two parts: 1) creating spheres for each cell in the dataset, then 2) creating an organizing hierarchy. The structure of the hierarchy varies depending on the topological characteristics of the dataset.

Once the tree is constructed, various geometric operations are available for quickly selecting cells based on sphere tree operations; for example, process all cells intersecting a plane (i.e., use the sphere tree to identify candidate cells for plane intersection).

This class does not necessarily create optimal sphere trees because some of its requirements (fast build time, provide simple reference code, a single bounding sphere per cell, etc.) precludes optimal performance. It is also oriented to computing on cells versus the classic problem of collision detection for polygonal models. For more information you want to read Gareth Bradshaw’s PhD thesis “Bounding Volume Hierarchies for Level-of-Detail Collision Handling” which does a nice job of laying out the challenges and important algorithms relative to sphere trees and BVH (bounding volume hierarchies).

@sa vtkSphereTreeFilter vtkPlaneCutter

Implementations

Source

impl vtkSphereTree

pub fn new() -> Self

Creates a new vtkSphereTree wrapped inside vtkNew