pub struct vtkUniformGridAMRAlgorithm(/* private fields */);Expand description
vtkUniformGridAMR as output.
A base class for all algorithms that take as input any type of data object including composite datasets and produce vtkUniformGridAMR in the output.
Implementations
Sourceimpl vtkUniformGridAMRAlgorithm
impl vtkUniformGridAMRAlgorithm
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkUniformGridAMRAlgorithm wrapped inside vtkNew