pub struct vtkAmoebaMinimizer(/* private fields */);Expand description
nonlinear optimization with a simplex
vtkAmoebaMinimizer will modify a set of parameters in order to find the minimum of a specified function. The method used is commonly known as the amoeba method, it constructs an n-dimensional simplex in parameter space (i.e. a tetrahedron if the number or parameters is 3) and moves the vertices around parameter space until a local minimum is found. The amoeba method is robust, reasonably efficient, but is not guaranteed to find the global minimum if several local minima exist.
Implementations
Sourceimpl vtkAmoebaMinimizer
impl vtkAmoebaMinimizer
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkAmoebaMinimizer wrapped inside vtkNew