pub struct vtkQuaternionInterpolator(/* private fields */);Expand description
interpolate a quaternion
This class is used to interpolate a series of quaternions representing the rotations of a 3D object. The interpolation may be linear in form (using spherical linear interpolation SLERP), or via spline interpolation (using SQUAD). In either case the interpolation is specialized to quaternions since the interpolation occurs on the surface of the unit quaternion sphere.
To use this class, specify at least two pairs of (t,q[4]) with the AddQuaternion() method. Next interpolate the tuples with the InterpolateQuaternion(t,q[4]) method, where “t” must be in the range of (t_min,t_max) parameter values specified by the AddQuaternion() method (t is clamped otherwise), and q[4] is filled in by the method.
There are several important background references. Ken Shoemake described the practical application of quaternions for the interpolation of rotation (K. Shoemake, “Animating rotation with quaternion curves”, Computer Graphics (Siggraph ’85) 19(3):245–254, 1985). Another fine reference (available on-line) is E. B. Dam, M. Koch, and M. Lillholm, Technical Report DIKU-TR-98/5, Dept. of Computer Science, University of Copenhagen, Denmark.
@warning Note that for two or less quaternions, Slerp (linear) interpolation is performed even if spline interpolation is requested. Also, the tangents to the first and last segments of spline interpolation are (arbitrarily) defined by repeating the first and last quaternions.
@warning There are several methods particular to quaternions (norms, products, etc.) implemented interior to this class. These may be moved to a separate quaternion class at some point.
@sa vtkQuaternion
Implementations
Sourceimpl vtkQuaternionInterpolator
impl vtkQuaternionInterpolator
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkQuaternionInterpolator wrapped inside vtkNew