vtkExprTkFunctionParser

Struct vtkExprTkFunctionParser 

pub struct vtkExprTkFunctionParser(/* private fields */);
Parse and evaluate a mathematical expression

vtkExprTkFunctionParser is a wrapper class of the ExprTK library that takes in a mathematical expression as a char string, parses it, and evaluates it at the specified values of the variables in the input string.

The detailed documentation of the supported functionality is described in https://github.com/ArashPartow/exprtk. In addition to the documented functionality, the following vector operations have been implemented:

  1. cross(v1, v2), cross product of two vectors,
  2. mag(v), magnitude of a vector,
  3. norm(v), the normalized version of a vector.

@par Thanks: Arash Partow for implementing the ExprTk library.

Implementations

Source

impl vtkExprTkFunctionParser

pub fn new() -> Self

Creates a new vtkExprTkFunctionParser wrapped inside vtkNew