vtkResourceFileLocator

Struct vtkResourceFileLocator 

pub struct vtkResourceFileLocator(/* private fields */);
utility to locate resource files.

VTK based application often need to locate resource files, such configuration files, Python modules, etc. vtkResourceFileLocator provides methods that can be used to locate such resource files at runtime.

Using Locate, one can locate files relative to an anchor directory such as the executable directory, or the library directory.

GetLibraryPathForSymbolUnix and GetLibraryPathForSymbolWin32 methods can be used to locate the library that provides a particular symbol. For example, this is used by vtkPythonInterpreter to ensure that the vtk Python package is located relative the VTK libraries, irrespective of the application location.

Implementations

Source

impl vtkResourceFileLocator

pub fn new() -> Self

Creates a new vtkResourceFileLocator wrapped inside vtkNew