pub struct vtkExecutableRunner(/* private fields */);Expand description
Launch a process on the current machine and get its output
Launch a process on the current machine and get its standard output and
standard error output. When ExecuteInSystemShell is false, arguments
needs to be added separately using the AddArgument / ClearArguments
API, otherwise command may not work correctly. If one does not know how to
parse the arguments of the command it want to execute then
ExecuteInSystemShell should be set to true.
Implementations
Sourceimpl vtkExecutableRunner
impl vtkExecutableRunner
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkExecutableRunner wrapped inside vtkNew