pub struct vtkSocketCollection(/* private fields */);Expand description
a collection for sockets.
Apart from being vtkCollection subclass for sockets, this class provides means to wait for activity on all the sockets in the collection simultaneously.
Implementations
Sourceimpl vtkSocketCollection
impl vtkSocketCollection
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkSocketCollection wrapped inside vtkNew