pub struct vtkCylindricalTransform(/* private fields */);Expand description
cylindrical to rectangular coords and back
vtkCylindricalTransform will convert (r,theta,z) coordinates to (x,y,z) coordinates and back again. The angles are given in radians. By default, it converts cylindrical coordinates to rectangular, but GetInverse() returns a transform that will do the opposite. The equation that is used is x = rcos(theta), y = rsin(theta), z = z. @warning This transform is not well behaved along the line x=y=0 (i.e. along the z-axis) @sa vtkSphericalTransform vtkGeneralTransform
Implementations
Sourceimpl vtkCylindricalTransform
impl vtkCylindricalTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkCylindricalTransform wrapped inside vtkNew