pub struct vtkGeneralTransform(/* private fields */);Expand description
allows operations on any transforms
vtkGeneralTransform is like vtkTransform and vtkPerspectiveTransform, but it will work with any vtkAbstractTransform as input. It is not as efficient as the other two, however, because arbitrary transformations cannot be concatenated by matrix multiplication. Transform concatenation is simulated by passing each input point through each transform in turn. @sa vtkTransform vtkPerspectiveTransform
Implementations
Sourceimpl vtkGeneralTransform
impl vtkGeneralTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkGeneralTransform wrapped inside vtkNew