pub struct vtkThinPlateSplineTransform(/* private fields */);Expand description
a nonlinear warp transformation
vtkThinPlateSplineTransform describes a nonlinear warp transform defined by a set of source and target landmarks. Any point on the mesh close to a source landmark will be moved to a place close to the corresponding target landmark. The points in between are interpolated smoothly using Bookstein’s Thin Plate Spline algorithm.
To obtain a correct TPS warp, use the R2LogR kernel if your data is 2D, and the R kernel if your data is 3D. Or you can specify your own RBF. (Hence this class is more general than a pure TPS transform.) @warning
- The inverse transform is calculated using an iterative method, and is several times more expensive than the forward transform.
- Whenever you add, subtract, or set points you must call Modified() on the vtkPoints object, or the transformation might not update.
- Collinear point configurations (except those that lie in the XY plane) result in an unstable transformation. Forward transform can be computed for any configuration by disabling bulk transform regularization. @sa vtkGridTransform vtkGeneralTransform
Implementations
Sourceimpl vtkThinPlateSplineTransform
impl vtkThinPlateSplineTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkThinPlateSplineTransform wrapped inside vtkNew