pub struct vtkTransform(/* private fields */);Expand description
describes linear transformations via a 4x4 matrix
A vtkTransform can be used to describe the full range of linear (also known as affine) coordinate transformations in three dimensions, which are internally represented as a 4x4 homogeneous transformation matrix. When you create a new vtkTransform, it is always initialized to the identity transformation.
The SetInput() method allows you to set another transform, instead of the identity transform, to be the base transformation. There is a pipeline mechanism to ensure that when the input is modified, the current transformation will be updated accordingly. This pipeline mechanism is also supported by the Concatenate() method.
Most of the methods for manipulating this transformation, e.g. Translate, Rotate, and Concatenate, can operate in either PreMultiply (the default) or PostMultiply mode. In PreMultiply mode, the translation, concatenation, etc. will occur before any transformations which are represented by the current matrix. In PostMultiply mode, the additional transformation will occur after any transformations represented by the current matrix.
This class performs all of its operations in a right handed coordinate system with right handed rotations. Some other graphics libraries use left handed coordinate systems and rotations. @sa vtkPerspectiveTransform vtkGeneralTransform vtkMatrix4x4 vtkTransformCollection vtkTransformFilter vtkTransformPolyDataFilter vtkImageReslice
Implementations
Sourceimpl vtkTransform
impl vtkTransform
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new vtkTransform wrapped inside vtkNew